@@ -1,10 +1,16 @@
 """Handles incoming appsync requests, invokes methods, returns responses."""
 
 import json
+import re
+from typing import Any
 from urllib.parse import unquote
+from uuid import uuid4
 
+from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
+from moto.core.utils import unix_time
 
+from .exceptions import ApiKeyValidityOutOfBoundsException, AWSValidationException
 from .models import AppSyncBackend, appsync_backends
 
 
@@ -14,6 +20,16 @@ class AppSyncResponse(BaseResponse):
     def __init__(self) -> None:
         super().__init__(service_name="appsync")
 
+    @staticmethod
+    def dns_event_response(request: Any, url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[misc]
+        data = json.loads(request.data.decode("utf-8"))
+
+        response: dict[str, list[Any]] = {"failed": [], "successful": []}
+        for idx in range(len(data.get("events", []))):
+            response["successful"].append({"identifier": str(uuid4()), "index": idx})
+
+        return 200, {}, json.dumps(response).encode("utf-8")
+
     @property
     def appsync_backend(self) -> AppSyncBackend:
         """Return backend instance specific for this region."""
@@ -32,6 +48,7 @@ class AppSyncResponse(BaseResponse):
         )
         xray_enabled = params.get("xrayEnabled", False)
         lambda_authorizer_config = params.get("lambdaAuthorizerConfig")
+        visibility = params.get("visibility")
         graphql_api = self.appsync_backend.create_graphql_api(
             name=name,
             log_config=log_config,
@@ -42,6 +59,7 @@ class AppSyncResponse(BaseResponse):
             xray_enabled=xray_enabled,
             lambda_authorizer_config=lambda_authorizer_config,
             tags=tags,
+            visibility=visibility,
         )
         response = graphql_api.to_json()
         response["tags"] = self.appsync_backend.list_tags_for_resource(graphql_api.arn)
@@ -98,6 +116,15 @@ class AppSyncResponse(BaseResponse):
         api_id = self.path.split("/")[-2]
         description = params.get("description")
         expires = params.get("expires")
+
+        if expires:
+            current_time = int(unix_time())
+            min_validity = current_time + 86400  # 1 day in seconds
+            if expires < min_validity:
+                raise ApiKeyValidityOutOfBoundsException(
+                    "API key must be valid for a minimum of 1 days."
+                )
+
         api_key = self.appsync_backend.create_api_key(
             api_id=api_id, description=description, expires=expires
         )
@@ -121,6 +148,16 @@ class AppSyncResponse(BaseResponse):
         params = json.loads(self.body)
         description = params.get("description")
         expires = params.get("expires")
+
+        # Validate that API key expires at least 1 day from now
+        if expires:
+            current_time = int(unix_time())
+            min_validity = current_time + 86400  # 1 day in seconds
+            if expires < min_validity:
+                raise ApiKeyValidityOutOfBoundsException(
+                    "API key must be valid for a minimum of 1 days."
+                )
+
         api_key = self.appsync_backend.update_api_key(
             api_id=api_id,
             api_key_id=api_key_id,
@@ -249,3 +286,104 @@ class AppSyncResponse(BaseResponse):
             api_id=api_id,
         )
         return "{}"
+
+    def create_api(self) -> str:
+        params = json.loads(self.body)
+        name = params.get("name")
+
+        if name:
+            pattern = r"^[A-Za-z0-9_\-\ ]+$"
+            if not re.match(pattern, name):
+                raise AWSValidationException(
+                    "1 validation error detected: "
+                    "Value at 'name' failed to satisfy constraint: "
+                    "Member must satisfy regular expression pattern: "
+                    "[A-Za-z0-9_\\-\\ ]+"
+                )
+
+        owner_contact = params.get("ownerContact")
+        tags = params.get("tags", {})
+        event_config = params.get("eventConfig")
+
+        api = self.appsync_backend.create_api(
+            name=name,
+            owner_contact=owner_contact,
+            tags=tags,
+            event_config=event_config,
+        )
+
+        response = api.to_json()
+        return json.dumps({"api": response})
+
+    def list_apis(self) -> str:
+        apis = self.appsync_backend.list_apis()
+        return json.dumps(dict(apis=[api.to_json() for api in apis]))
+
+    def delete_api(self) -> str:
+        api_id = self.path.split("/")[-1]
+        self.appsync_backend.delete_api(api_id=api_id)
+        return "{}"
+
+    def create_channel_namespace(self) -> str:
+        params = json.loads(self.body)
+        api_id = self.path.split("/")[-2]
+        name = params.get("name")
+
+        if name:
+            pattern = r"^[A-Za-z0-9](?:[A-Za-z0-9\-]{0,48}[A-Za-z0-9])?$"
+            if not re.match(pattern, name):
+                raise AWSValidationException(
+                    "1 validation error detected: "
+                    "Value at 'name' failed to satisfy constraint: "
+                    "Member must satisfy regular expression pattern: "
+                    "([A-Za-z0-9](?:[A-Za-z0-9\\-]{0,48}[A-Za-z0-9])?)"
+                )
+
+        subscribe_auth_modes = params.get("subscribeAuthModes")
+        publish_auth_modes = params.get("publishAuthModes")
+        code_handlers = params.get("codeHandlers")
+        tags = params.get("tags", {})
+        handler_configs = params.get("handlerConfigs", {})
+
+        channel_namespace = self.appsync_backend.create_channel_namespace(
+            api_id=api_id,
+            name=name,
+            subscribe_auth_modes=subscribe_auth_modes,
+            publish_auth_modes=publish_auth_modes,
+            code_handlers=code_handlers,
+            tags=tags,
+            handler_configs=handler_configs,
+        )
+
+        return json.dumps({"channelNamespace": channel_namespace.to_json()})
+
+    def list_channel_namespaces(self) -> str:
+        api_id = self.path.split("/")[-2]
+        channel_namespaces = self.appsync_backend.list_channel_namespaces(api_id=api_id)
+        return json.dumps(
+            dict(
+                channelNamespaces=[
+                    channel_namespace.to_json()
+                    for channel_namespace in channel_namespaces
+                ]
+            )
+        )
+
+    def delete_channel_namespace(self) -> str:
+        path_parts = self.path.split("/")
+        api_id = path_parts[-3]
+        name = path_parts[-1]
+
+        self.appsync_backend.delete_channel_namespace(
+            api_id=api_id,
+            name=name,
+        )
+        return "{}"
+
+    def get_api(self) -> str:
+        api_id = self.path.split("/")[-1]
+
+        api = self.appsync_backend.get_api(api_id=api_id)
+        response = api.to_json()
+        response["tags"] = self.appsync_backend.list_tags_for_resource(api.api_arn)
+        return json.dumps(dict(api=response))
