@@ -68,7 +68,7 @@ class WorkGroup(TaggableResourceMixin, BaseModel):
             self.configuration["EnforceWorkGroupConfiguration"] = True
         if "EngineVersion" not in self.configuration:
             self.configuration["EngineVersion"] = {
-                "EffectiveEngineVersion": "Athena engine " "version 3",
+                "EffectiveEngineVersion": "Athena engine version 3",
                 "SelectedEngineVersion": "AUTO",
             }
         if "PublishCloudWatchMetricsEnabled" not in self.configuration:
@@ -117,6 +117,7 @@ class Execution(BaseModel):
         self.workgroup = workgroup
         self.execution_parameters = execution_parameters
         self.start_time = time.time()
+        self.end_time = time.time()
         self.status = "SUCCEEDED"
 
         if self.config is not None and "OutputLocation" in self.config:
@@ -346,7 +347,7 @@ class AthenaBackend(BaseBackend):
             for row in self.query_results[exec_id].rows:
                 query_result += ",".join(
                     [
-                        f"\"{r['VarCharValue']}\"" if "VarCharValue" in r else ""
+                        f'"{r["VarCharValue"]}"' if "VarCharValue" in r else ""
                         for r in row["Data"]
                     ]
                 )
@@ -452,5 +453,12 @@ class AthenaBackend(BaseBackend):
                 return ps
         return None
 
+    def get_query_runtime_statistics(
+        self, query_execution_id: str
+    ) -> Optional[Execution]:
+        if query_execution_id in self.executions:
+            return self.executions[query_execution_id]
+        return None
+
 
 athena_backends = BackendDict(AthenaBackend, "athena")
