@@ -10,6 +10,7 @@ from moto.ec2 import ec2_backends
 from moto.ec2.exceptions import InvalidInstanceIdError
 from moto.ec2.models import EC2Backend
 from moto.ec2.models.instances import Instance
+from moto.ec2.models.launch_templates import LaunchTemplate
 from moto.elb.exceptions import LoadBalancerNotFoundError
 from moto.elb.models import ELBBackend, elb_backends
 from moto.elbv2.models import ELBv2Backend, elbv2_backends
@@ -458,8 +459,9 @@ class FakeAutoScalingGroup(CloudFormationModel):
         self.max_size = max_size
         self.min_size = min_size
 
-        self.launch_template = None
-        self.launch_config = None
+        self.launch_template: Optional[LaunchTemplate] = None
+        # Will be None if self.launch_template is used instead
+        self.launch_config: FakeLaunchConfiguration = None  # type: ignore[assignment]
 
         self._set_launch_configuration(
             launch_config_name, launch_template, mixed_instances_policy
@@ -487,7 +489,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
 
         self.metrics: List[str] = []
         self.warm_pool: Optional[FakeWarmPool] = None
-        self.created_time = created_time
+        self.created_time = created_time.isoformat()
 
     @property
     def tags(self) -> List[Dict[str, str]]:
@@ -720,6 +722,13 @@ class FakeAutoScalingGroup(CloudFormationModel):
 
         return self.launch_config.security_groups  # type: ignore[union-attr]
 
+    @property
+    def instance_tags(self) -> Dict[str, str]:
+        if self.launch_template:
+            version = self.launch_template.get_version(self.launch_template_version)
+            return version.instance_tags
+        return {}
+
     def update(
         self,
         availability_zones: List[str],
@@ -815,6 +824,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
         self, count_needed: int, propagated_tags: Dict[str, str]
     ) -> None:
         propagated_tags[ASG_NAME_TAG] = self.name
+        propagated_tags.update(self.instance_tags)
 
         # VPCZoneIdentifier:
         # A comma-separated list of subnet IDs for a virtual private cloud (VPC) where instances in the Auto Scaling group can be created.
@@ -827,6 +837,12 @@ class FakeAutoScalingGroup(CloudFormationModel):
             if self.launch_config
             else None
         )
+        launch_template = None
+        if self.launch_template:
+            if self.launch_template.id:
+                launch_template = {"LaunchTemplateId": self.launch_template.id}
+            elif self.launch_template.name:
+                launch_template = {"LaunchTemplateName": self.launch_template.name}
         reservation = self.autoscaling_backend.ec2_backend.run_instances(
             self.image_id,
             count_needed,
@@ -836,6 +852,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
             tags={"instance": propagated_tags},
             placement=random.choice(self.availability_zones),
             launch_config=self.launch_config,
+            launch_template=launch_template,
             is_instance_type_default=False,
             associate_public_ip=associate_public_ip,
             subnet_id=subnet_id,
