@@ -1,9 +1,10 @@
-from moto.core.responses import BaseResponse
-from moto.utilities.aws_headers import amzn_request_id
-from .models import batch_backends, BatchBackend
-from urllib.parse import urlsplit, unquote
-
 import json
+from urllib.parse import unquote, urlsplit
+
+from moto.core.models import default_user_config
+from moto.core.responses import BaseResponse
+
+from .models import BatchBackend, batch_backends
 
 
 class BatchResponse(BaseResponse):
@@ -12,39 +13,38 @@ class BatchResponse(BaseResponse):
 
     @property
     def batch_backend(self) -> BatchBackend:
-        """
-        :return: Batch Backend
-        :rtype: moto.batch.models.BatchBackend
-        """
-        return batch_backends[self.current_account][self.region]
+        if default_user_config.get("batch", {}).get("use_docker", True) is False:
+            from moto.batch_simple.models import batch_simple_backends
+
+            return batch_simple_backends[self.current_account][self.region]
+        else:
+            return batch_backends[self.current_account][self.region]
 
     def _get_action(self) -> str:
         # Return element after the /v1/*
         return urlsplit(self.uri).path.lstrip("/").split("/")[1]
 
-    # CreateComputeEnvironment
-    @amzn_request_id
     def createcomputeenvironment(self) -> str:
         compute_env_name = self._get_param("computeEnvironmentName")
         compute_resource = self._get_param("computeResources")
         service_role = self._get_param("serviceRole")
         state = self._get_param("state")
         _type = self._get_param("type")
+        tags = self._get_param("tags")
 
-        name, arn = self.batch_backend.create_compute_environment(
+        env = self.batch_backend.create_compute_environment(
             compute_environment_name=compute_env_name,
             _type=_type,
             state=state,
             compute_resources=compute_resource,
             service_role=service_role,
+            tags=tags,
         )
 
-        result = {"computeEnvironmentArn": arn, "computeEnvironmentName": name}
+        result = {"computeEnvironmentArn": env.arn, "computeEnvironmentName": env.name}
 
         return json.dumps(result)
 
-    # DescribeComputeEnvironments
-    @amzn_request_id
     def describecomputeenvironments(self) -> str:
         compute_environments = self._get_param("computeEnvironments")
 
@@ -53,8 +53,6 @@ class BatchResponse(BaseResponse):
         result = {"computeEnvironments": envs}
         return json.dumps(result)
 
-    # DeleteComputeEnvironment
-    @amzn_request_id
     def deletecomputeenvironment(self) -> str:
         compute_environment = self._get_param("computeEnvironment")
 
@@ -62,8 +60,6 @@ class BatchResponse(BaseResponse):
 
         return ""
 
-    # UpdateComputeEnvironment
-    @amzn_request_id
     def updatecomputeenvironment(self) -> str:
         compute_env_name = self._get_param("computeEnvironment")
         compute_resource = self._get_param("computeResources")
@@ -81,8 +77,6 @@ class BatchResponse(BaseResponse):
 
         return json.dumps(result)
 
-    # CreateJobQueue
-    @amzn_request_id
     def createjobqueue(self) -> str:
         compute_env_order = self._get_param("computeEnvironmentOrder")
         queue_name = self._get_param("jobQueueName")
@@ -91,7 +85,7 @@ class BatchResponse(BaseResponse):
         state = self._get_param("state")
         tags = self._get_param("tags")
 
-        name, arn = self.batch_backend.create_job_queue(
+        queue = self.batch_backend.create_job_queue(
             queue_name=queue_name,
             priority=priority,
             schedule_policy=schedule_policy,
@@ -100,12 +94,10 @@ class BatchResponse(BaseResponse):
             tags=tags,
         )
 
-        result = {"jobQueueArn": arn, "jobQueueName": name}
+        result = {"jobQueueArn": queue.arn, "jobQueueName": queue.name}
 
         return json.dumps(result)
 
-    # DescribeJobQueues
-    @amzn_request_id
     def describejobqueues(self) -> str:
         job_queues = self._get_param("jobQueues")
 
@@ -114,8 +106,6 @@ class BatchResponse(BaseResponse):
         result = {"jobQueues": queues}
         return json.dumps(result)
 
-    # UpdateJobQueue
-    @amzn_request_id
     def updatejobqueue(self) -> str:
         compute_env_order = self._get_param("computeEnvironmentOrder")
         queue_name = self._get_param("jobQueue")
@@ -135,8 +125,6 @@ class BatchResponse(BaseResponse):
 
         return json.dumps(result)
 
-    # DeleteJobQueue
-    @amzn_request_id
     def deletejobqueue(self) -> str:
         queue_name = self._get_param("jobQueue")
 
@@ -144,8 +132,6 @@ class BatchResponse(BaseResponse):
 
         return ""
 
-    # RegisterJobDefinition
-    @amzn_request_id
     def registerjobdefinition(self) -> str:
         container_properties = self._get_param("containerProperties")
         node_properties = self._get_param("nodeProperties")
@@ -157,7 +143,7 @@ class BatchResponse(BaseResponse):
         timeout = self._get_param("timeout")
         platform_capabilities = self._get_param("platformCapabilities")
         propagate_tags = self._get_param("propagateTags")
-        name, arn, revision = self.batch_backend.register_job_definition(
+        job_def = self.batch_backend.register_job_definition(
             def_name=def_name,
             parameters=parameters,
             _type=_type,
@@ -171,15 +157,13 @@ class BatchResponse(BaseResponse):
         )
 
         result = {
-            "jobDefinitionArn": arn,
-            "jobDefinitionName": name,
-            "revision": revision,
+            "jobDefinitionArn": job_def.arn,
+            "jobDefinitionName": job_def.name,
+            "revision": job_def.revision,
         }
 
         return json.dumps(result)
 
-    # DeregisterJobDefinition
-    @amzn_request_id
     def deregisterjobdefinition(self) -> str:
         queue_name = self._get_param("jobDefinition")
 
@@ -187,8 +171,6 @@ class BatchResponse(BaseResponse):
 
         return ""
 
-    # DescribeJobDefinitions
-    @amzn_request_id
     def describejobdefinitions(self) -> str:
         job_def_name = self._get_param("jobDefinitionName")
         job_def_list = self._get_param("jobDefinitions")
@@ -201,8 +183,6 @@ class BatchResponse(BaseResponse):
         result = {"jobDefinitions": [job.describe() for job in job_defs]}
         return json.dumps(result)
 
-    # SubmitJob
-    @amzn_request_id
     def submitjob(self) -> str:
         container_overrides = self._get_param("containerOverrides")
         depends_on = self._get_param("dependsOn")
@@ -211,6 +191,7 @@ class BatchResponse(BaseResponse):
         job_queue = self._get_param("jobQueue")
         timeout = self._get_param("timeout")
         array_properties = self._get_param("arrayProperties", {})
+        parameters = self._get_param("parameters")
 
         name, job_id, job_arn = self.batch_backend.submit_job(
             job_name,
@@ -220,33 +201,34 @@ class BatchResponse(BaseResponse):
             container_overrides=container_overrides,
             timeout=timeout,
             array_properties=array_properties,
+            parameters=parameters,
         )
 
         result = {"jobId": job_id, "jobName": name, "jobArn": job_arn}
 
         return json.dumps(result)
 
-    # DescribeJobs
-    @amzn_request_id
     def describejobs(self) -> str:
         jobs = self._get_param("jobs")
 
         return json.dumps({"jobs": self.batch_backend.describe_jobs(jobs)})
 
-    # ListJobs
-    @amzn_request_id
     def listjobs(self) -> str:
         job_queue = self._get_param("jobQueue")
         job_status = self._get_param("jobStatus")
         filters = self._get_param("filters")
+        array_job_id = self._get_param("arrayJobId")
 
-        jobs = self.batch_backend.list_jobs(job_queue, job_status, filters)
+        jobs = self.batch_backend.list_jobs(
+            job_queue_name=job_queue,
+            array_job_id=array_job_id,
+            job_status=job_status,
+            filters=filters,
+        )
 
         result = {"jobSummaryList": [job.describe_short() for job in jobs]}
         return json.dumps(result)
 
-    # TerminateJob
-    @amzn_request_id
     def terminatejob(self) -> str:
         job_id = self._get_param("jobId")
         reason = self._get_param("reason")
@@ -255,8 +237,6 @@ class BatchResponse(BaseResponse):
 
         return ""
 
-    # CancelJob
-    @amzn_request_id
     def canceljob(self) -> str:
         job_id = self._get_param("jobId")
         reason = self._get_param("reason")
@@ -264,7 +244,6 @@ class BatchResponse(BaseResponse):
 
         return ""
 
-    @amzn_request_id
     def tags(self) -> str:
         resource_arn = unquote(self.path).split("/v1/tags/")[-1]
         tags = self._get_param("tags")
@@ -278,7 +257,6 @@ class BatchResponse(BaseResponse):
             self.batch_backend.untag_resource(resource_arn, tag_keys)  # type: ignore[arg-type]
         return ""
 
-    @amzn_request_id
     def createschedulingpolicy(self) -> str:
         body = json.loads(self.body)
         name = body.get("name")
@@ -289,26 +267,22 @@ class BatchResponse(BaseResponse):
         )
         return json.dumps(policy.to_dict(create=True))
 
-    @amzn_request_id
     def describeschedulingpolicies(self) -> str:
         body = json.loads(self.body)
         arns = body.get("arns") or []
         policies = self.batch_backend.describe_scheduling_policies(arns)
         return json.dumps({"schedulingPolicies": [pol.to_dict() for pol in policies]})
 
-    @amzn_request_id
     def listschedulingpolicies(self) -> str:
         arns = self.batch_backend.list_scheduling_policies()
         return json.dumps({"schedulingPolicies": [{"arn": arn} for arn in arns]})
 
-    @amzn_request_id
     def deleteschedulingpolicy(self) -> str:
         body = json.loads(self.body)
         arn = body["arn"]
         self.batch_backend.delete_scheduling_policy(arn)
         return ""
 
-    @amzn_request_id
     def updateschedulingpolicy(self) -> str:
         body = json.loads(self.body)
         arn = body.get("arn")
