@@ -1,5 +1,4 @@
 import json
-import re
 from typing import Any, Dict
 
 from moto.core.responses import TYPE_RESPONSE, BaseResponse
@@ -258,9 +257,7 @@ class CognitoIdpResponse(BaseResponse):
         groups, token = self.backend.list_groups(
             user_pool_id, limit=limit, next_token=token
         )
-        response = {"Groups": [group.to_json() for group in groups]}
-        if token:
-            response["NextToken"] = token
+        response = {"Groups": [group.to_json() for group in groups], "NextToken": token}
         return json.dumps(response)
 
     def delete_group(self) -> str:
@@ -299,9 +296,10 @@ class CognitoIdpResponse(BaseResponse):
         users, token = self.backend.list_users_in_group(
             user_pool_id, group_name, limit=limit, next_token=token
         )
-        response = {"Users": [user.to_json(extended=True) for user in users]}
-        if token:
-            response["NextToken"] = token
+        response = {
+            "Users": [user.to_json(extended=True) for user in users],
+            "NextToken": token,
+        }
         return json.dumps(response)
 
     def admin_list_groups_for_user(self) -> str:
@@ -312,9 +310,7 @@ class CognitoIdpResponse(BaseResponse):
         groups, token = self.backend.admin_list_groups_for_user(
             user_pool_id, username, limit=limit, next_token=token
         )
-        response = {"Groups": [group.to_json() for group in groups]}
-        if token:
-            response["NextToken"] = token
+        response = {"Groups": [group.to_json() for group in groups], "NextToken": token}
         return json.dumps(response)
 
     def admin_remove_user_from_group(self) -> str:
@@ -371,52 +367,8 @@ class CognitoIdpResponse(BaseResponse):
         filt = self._get_param("Filter")
         attributes_to_get = self._get_param("AttributesToGet")
         users, token = self.backend.list_users(
-            user_pool_id, limit=limit, pagination_token=token
+            user_pool_id, filt, limit=limit, pagination_token=token
         )
-        if filt:
-            inherent_attributes: Dict[str, Any] = {
-                "cognito:user_status": lambda u: u.status,
-                "status": lambda u: "Enabled" if u.enabled else "Disabled",
-                "username": lambda u: u.username,
-            }
-            comparisons: Dict[str, Any] = {
-                "=": lambda x, y: x == y,
-                "^=": lambda x, y: x.startswith(y),
-            }
-            allowed_attributes = [
-                "username",
-                "email",
-                "phone_number",
-                "name",
-                "given_name",
-                "family_name",
-                "preferred_username",
-                "cognito:user_status",
-                "status",
-                "sub",
-            ]
-
-            match = re.match(r"([\w:]+)\s*(=|\^=)\s*\"(.*)\"", filt)
-            if match:
-                name, op, value = match.groups()
-            else:
-                raise InvalidParameterException("Error while parsing filter")
-            if name not in allowed_attributes:
-                raise InvalidParameterException(f"Invalid search attribute: {name}")
-            compare = comparisons[op]
-            users = [
-                user
-                for user in users
-                if [
-                    attr
-                    for attr in user.attributes
-                    if attr["Name"] == name and compare(attr["Value"], value)
-                ]
-                or (
-                    name in inherent_attributes
-                    and compare(inherent_attributes[name](user), value)
-                )
-            ]
         response: Dict[str, Any] = {
             "Users": [
                 user.to_json(extended=True, attributes_to_get=attributes_to_get)
@@ -624,20 +576,24 @@ class CognitoIdpResponse(BaseResponse):
     def associate_software_token(self) -> str:
         access_token = self._get_param("AccessToken")
         session = self._get_param("Session")
-        result = self.backend.associate_software_token(access_token, session)
+        result = self._get_region_agnostic_backend().associate_software_token(
+            access_token, session
+        )
         return json.dumps(result)
 
     def verify_software_token(self) -> str:
         access_token = self._get_param("AccessToken")
         session = self._get_param("Session")
-        result = self.backend.verify_software_token(access_token, session)
+        result = self._get_region_agnostic_backend().verify_software_token(
+            access_token, session
+        )
         return json.dumps(result)
 
     def set_user_mfa_preference(self) -> str:
         access_token = self._get_param("AccessToken")
         software_token_mfa_settings = self._get_param("SoftwareTokenMfaSettings")
         sms_mfa_settings = self._get_param("SMSMfaSettings")
-        self.backend.set_user_mfa_preference(
+        self._get_region_agnostic_backend().set_user_mfa_preference(
             access_token, software_token_mfa_settings, sms_mfa_settings
         )
         return ""
@@ -671,7 +627,9 @@ class CognitoIdpResponse(BaseResponse):
     def update_user_attributes(self) -> str:
         access_token = self._get_param("AccessToken")
         attributes = self._get_param("UserAttributes")
-        self.backend.update_user_attributes(access_token, attributes)
+        self._get_region_agnostic_backend().update_user_attributes(
+            access_token, attributes
+        )
         return json.dumps({})
 
 
