@@ -1,6 +1,9 @@
 import json
+from typing import Any, Dict
+
 from moto.core.responses import BaseResponse
-from .models import config_backends, ConfigBackend
+
+from .models import ConfigBackend, config_backends
 
 
 class ConfigResponse(BaseResponse):
@@ -116,12 +119,11 @@ class ConfigResponse(BaseResponse):
 
     def list_discovered_resources(self) -> str:
         schema = self.config_backend.list_discovered_resources(
-            self._get_param("resourceType"),
-            self.region,
-            self._get_param("resourceIds"),
-            self._get_param("resourceName"),
-            self._get_param("limit"),
-            self._get_param("nextToken"),
+            resource_type=self._get_param("resourceType"),
+            resource_ids=self._get_param("resourceIds"),
+            resource_name=self._get_param("resourceName"),
+            limit=self._get_param("limit"),
+            next_token=self._get_param("nextToken"),
         )
         return json.dumps(schema)
 
@@ -235,3 +237,75 @@ class ConfigResponse(BaseResponse):
     def delete_config_rule(self) -> str:
         self.config_backend.delete_config_rule(self._get_param("ConfigRuleName"))
         return ""
+
+    def put_retention_configuration(self) -> str:
+        retention_configuration = self.config_backend.put_retention_configuration(
+            self._get_param("RetentionPeriodInDays")
+        )
+        return json.dumps(retention_configuration)
+
+    def describe_retention_configurations(self) -> str:
+        retention_configurations = (
+            self.config_backend.describe_retention_configurations(
+                self._get_param("RetentionConfigurationNames")
+            )
+        )
+        schema = {"RetentionConfigurations": retention_configurations}
+        return json.dumps(schema)
+
+    def delete_retention_configuration(self) -> str:
+        self.config_backend.delete_retention_configuration(
+            self._get_param("RetentionConfigurationName")
+        )
+        return ""
+
+    def select_resource_config(self) -> str:
+        params = self._get_params()
+        expression: str = params.get("Expression", "")
+        limit = params.get("Limit")
+        next_token = params.get("NextToken")
+        results, query_info, next_token = self.config_backend.select_resource_config(
+            expression=expression,
+            limit=limit,
+            next_token=next_token,
+        )
+
+        response: Dict[str, Any] = {"Results": results}
+        if query_info:
+            response["QueryInfo"] = query_info
+
+        if next_token:
+            response["NextToken"] = next_token
+
+        return json.dumps(response)
+
+    def put_resource_config(self) -> str:
+        params = json.loads(self.body)
+        resource_type: str = params.get("ResourceType", "")
+        schema_version_id: str = params.get("SchemaVersionId", "")
+        resource_id: str = params.get("ResourceId", "")
+        resource_name: str = params.get("ResourceName", "")
+        configuration = params.get("Configuration", {})
+        configuration_str: str = json.dumps(configuration) if configuration else ""
+        tags: Dict[str, str] = params.get("Tags", {})
+        self.config_backend.put_resource_config(
+            resource_type=resource_type,
+            schema_version_id=schema_version_id,
+            resource_id=resource_id,
+            resource_name=resource_name,
+            configuration=configuration_str,
+            tags=tags,
+        )
+        return json.dumps(dict())
+
+    def delete_resource_config(self) -> str:
+        params = json.loads(self.body)
+        resource_type = params.get("ResourceType", "")
+        resource_id = params.get("ResourceId", "")
+
+        self.config_backend.delete_resource_config(
+            resource_type=resource_type,
+            resource_id=resource_id,
+        )
+
+        return json.dumps(dict())
