@@ -1,5 +1,6 @@
 """DirectoryServiceBackend class with methods for supported APIs."""
 
+import copy
 from typing import Any, Dict, List, Optional, Tuple
 
 from moto.core.base_backend import BackendDict, BaseBackend
@@ -15,7 +16,7 @@ from moto.ds.exceptions import (
     UnsupportedOperationException,
     ValidationException,
 )
-from moto.ds.utils import PAGINATION_MODEL
+from moto.ds.utils import PAGINATION_MODEL, SETTINGS_ENTRIES_MODEL
 from moto.ds.validations import validate_args
 from moto.ec2 import ec2_backends
 from moto.ec2.exceptions import InvalidSubnetIdError
@@ -38,6 +39,20 @@ class LdapsSettingInfo(BaseModel):
         }
 
 
+class LogSubscription(BaseModel):
+    def __init__(self, directory_id: str, log_group_name: str) -> None:
+        self.directory_id = directory_id
+        self.log_group_name = log_group_name
+        self.created_date_time = unix_time()
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "SubscriptionCreatedDateTime": self.created_date_time,
+            "DirectoryId": self.directory_id,
+            "LogGroupName": self.log_group_name,
+        }
+
+
 class Trust(BaseModel):
     def __init__(
         self,
@@ -79,7 +94,7 @@ class Trust(BaseModel):
         }
 
 
-class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
+class Directory(BaseModel):
     """Representation of a Simple AD Directory.
 
     When the "create" API for a Simple AD or a Microsoft AD directory is
@@ -116,7 +131,7 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
         short_name: Optional[str] = None,
         description: Optional[str] = None,
         edition: Optional[str] = None,
-    ):  # pylint: disable=too-many-arguments
+    ):
         self.account_id = account_id
         self.region = region
         self.name = name
@@ -138,9 +153,13 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
         self.stage = "Active"
         self.launch_time = unix_time()
         self.stage_last_updated_date_time = unix_time()
-        # add type annotation to line below
         self.ldaps_settings_info: List[LdapsSettingInfo] = []
         self.trusts: List[Trust] = []
+        self.settings = (
+            copy.deepcopy(SETTINGS_ENTRIES_MODEL)
+            if self.directory_type == "MicrosoftAD"
+            else []
+        )
 
         if self.directory_type == "ADConnector":
             self.security_group_id = self.create_security_group(
@@ -273,6 +292,7 @@ class DirectoryServiceBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
         self.directories: Dict[str, Directory] = {}
+        self.log_subscriptions: Dict[str, LogSubscription] = {}
         self.tagger = TaggingService()
 
     def _verify_subnets(self, region: str, vpc_settings: Dict[str, Any]) -> None:
@@ -320,7 +340,7 @@ class DirectoryServiceBackend(BaseBackend):
         size: str,
         connect_settings: Dict[str, Any],
         tags: List[Dict[str, str]],
-    ) -> str:  # pylint: disable=too-many-arguments
+    ) -> str:
         """Create a fake AD Connector."""
         if len(self.directories) > Directory.CONNECTED_DIRECTORIES_LIMIT:
             raise DirectoryLimitExceededException(
@@ -380,7 +400,7 @@ class DirectoryServiceBackend(BaseBackend):
         size: str,
         vpc_settings: Dict[str, Any],
         tags: List[Dict[str, str]],
-    ) -> str:  # pylint: disable=too-many-arguments
+    ) -> str:
         """Create a fake Simple Ad Directory."""
         if len(self.directories) > Directory.CLOUDONLY_DIRECTORIES_LIMIT:
             raise DirectoryLimitExceededException(
@@ -464,7 +484,7 @@ class DirectoryServiceBackend(BaseBackend):
         vpc_settings: Dict[str, Any],
         edition: str,
         tags: List[Dict[str, str]],
-    ) -> str:  # pylint: disable=too-many-arguments
+    ) -> str:
         """Create a fake Microsoft Ad Directory."""
         if len(self.directories) > Directory.CLOUDONLY_MICROSOFT_AD_LIMIT:
             raise DirectoryLimitExceededException(
@@ -641,16 +661,23 @@ class DirectoryServiceBackend(BaseBackend):
 
     @paginate(pagination_model=PAGINATION_MODEL)
     def describe_trusts(
-        self, directory_id: str, trust_ids: Optional[List[str]]
+        self, directory_id: Optional[str], trust_ids: Optional[List[str]]
     ) -> List[Trust]:
-        self._validate_directory_id(directory_id)
-        directory = self.directories[directory_id]
-        trusts = directory.trusts
-        if trust_ids:
-            trusts = [t for t in directory.trusts if t.trust_id in trust_ids]
-        else:
+        if directory_id:
+            self._validate_directory_id(directory_id)
+            directory = self.directories[directory_id]
             trusts = directory.trusts
-        return trusts
+        else:
+            trusts = [
+                trust
+                for directory in self.directories.values()
+                for trust in directory.trusts
+            ]
+        if trust_ids:
+            queried_trusts = [t for t in trusts if t.trust_id in trust_ids]
+        else:
+            queried_trusts = trusts
+        return queried_trusts
 
     def delete_trust(
         self, trust_id: str, delete_associated_conditional_forwarder: Optional[bool]
@@ -692,5 +719,78 @@ class DirectoryServiceBackend(BaseBackend):
         directory = self.directories[directory_id]
         directory.enable_ldaps(False)
 
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def describe_settings(
+        self, directory_id: str, status: Optional[str]
+    ) -> List[Dict[str, str]]:
+        """Describe settings for a Directory"""
+        self._validate_directory_id(directory_id)
+        directory = self.directories[directory_id]
+        if directory.directory_type not in ("MicrosoftAD"):
+            raise InvalidParameterException(
+                "This operation is only supported for Microsoft AD"
+            )
+        if status:
+            queried_settings = [
+                setting
+                for setting in directory.settings
+                if setting["RequestStatus"] == status
+            ]
+        else:
+            queried_settings = directory.settings
+        return queried_settings
+
+    def update_settings(self, directory_id: str, settings: List[Dict[str, Any]]) -> str:
+        self._validate_directory_id(directory_id)
+        directory = self.directories[directory_id]
+        if directory.directory_type not in ("MicrosoftAD"):
+            raise InvalidParameterException(
+                "This operation is only supported for Microsoft AD"
+            )
+        for s in settings:
+            for setting in directory.settings:
+                if setting["Name"] == s["Name"]:
+                    # TODO: Add validation for the value
+                    setting["AppliedValue"] = s["Value"]
+
+        return directory_id
+
+    def create_log_subscription(self, directory_id: str, log_group_name: str) -> None:
+        self._validate_directory_id(directory_id)
+        log_subscription = LogSubscription(directory_id, log_group_name)
+        if directory_id not in self.log_subscriptions:
+            self.log_subscriptions[directory_id] = log_subscription
+        else:
+            raise EntityAlreadyExistsException("Log subscription already exists")
+        return
+
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def list_log_subscriptions(
+        self,
+        directory_id: str,
+    ) -> List[LogSubscription]:
+        if directory_id:
+            self._validate_directory_id(directory_id)
+            log_subscription = self.log_subscriptions.get(directory_id, None)
+            if log_subscription:
+                log_subscriptions = [log_subscription]
+            else:
+                log_subscriptions = []
+        else:
+            log_subscriptions = [
+                log_subscription for log_subscription in self.log_subscriptions.values()
+            ]
+        return log_subscriptions
+
+    def delete_log_subscription(self, directory_id: str) -> None:
+        self._validate_directory_id(directory_id)
+        if directory_id in self.log_subscriptions:
+            self.log_subscriptions.pop(directory_id)
+        else:
+            raise EntityDoesNotExistException(
+                f"Log subscription for {directory_id} does not exist"
+            )
+        return
+
 
 ds_backends = BackendDict(DirectoryServiceBackend, service_name="ds")
