@@ -62,7 +62,7 @@ class IamInstanceProfileAssociationBackend:
         iam_instance_profile_association = IamInstanceProfileAssociation(
             self,
             iam_association_id,
-            self.get_instance(instance_id) if instance_id else None,  # type: ignore[attr-defined]
+            self.get_instance(instance_id) if instance_id else None,  # type: ignore[attr-defined, arg-type]
             instance_profile,
         )
         # Regarding to AWS there can be only one association with ec2.
@@ -114,6 +114,11 @@ class IamInstanceProfileAssociationBackend:
                 )
                 del self.iam_instance_profile_associations[association_key]
                 # Deleting once and avoiding `RuntimeError: dictionary changed size during iteration`
+
+                iam_instance_profile_association.ec2_backend.modify_instance_attribute(
+                    association_key, "iam_instance_profile", None
+                )
+
                 break
 
         if not iam_instance_profile_association:
