@@ -370,7 +370,7 @@ class SpotFleetRequest(TaggedEC2Resource, CloudFormationModel):
 
             if new_fulfilled_capacity - spec.weighted_capacity < self.target_capacity:
                 continue
-            new_fulfilled_capacity -= spec.weighted_capacity  # pylint: disable=W0631
+            new_fulfilled_capacity -= spec.weighted_capacity
             instance_ids.append(instance.id)
 
         self.spot_requests = [
