@@ -1,12 +1,32 @@
+import itertools
+from datetime import datetime
 from typing import Any, Dict, List, Optional
 
-from moto.core.utils import iso_8601_datetime_with_milliseconds, utcnow
+from moto.core.utils import utcnow
 from moto.utilities.utils import filter_resources
 
 from ..utils import random_transit_gateway_route_table_id
 from .core import TaggedEC2Resource
 
 
+class RouteTableAssociation:
+    def __init__(self) -> None:
+        self.resourceId = ""
+        self.resourceType = ""
+        self.state = ""
+        self.transitGatewayAttachmentId = ""
+
+    def clear(self) -> None:
+        self.resourceId = ""
+        self.resourceType = ""
+        self.state = ""
+        self.transitGatewayAttachmentId = ""
+
+
+class RouteTablePropagation(RouteTableAssociation):
+    pass
+
+
 class TransitGatewayRouteTable(TaggedEC2Resource):
     def __init__(
         self,
@@ -27,16 +47,20 @@ class TransitGatewayRouteTable(TaggedEC2Resource):
         self.state = "available"
         self.routes: Dict[str, Dict[str, Optional[str]]] = {}
         self.add_tags(tags or {})
-        self.route_table_association: Dict[str, str] = {}
-        self.route_table_propagation: List[Dict[str, str]] = []
+        self.route_table_association = RouteTableAssociation()
+        self.route_table_propagation: List[RouteTablePropagation] = []
 
     @property
     def physical_resource_id(self) -> str:
         return self.id
 
     @property
-    def create_time(self) -> str:
-        return iso_8601_datetime_with_milliseconds(self._created_at)
+    def create_time(self) -> datetime:
+        return self._created_at
+
+    @property
+    def creation_time(self) -> datetime:
+        return self.create_time
 
 
 class TransitGatewayRelations:
@@ -134,7 +158,7 @@ class TransitGatewayRouteTableBackend:
         )
         transit_gateways_route_table.routes[destination_cidr_block] = {
             "destinationCidrBlock": destination_cidr_block,
-            "prefixListId": "",
+            "prefixListId": None,
             "state": "blackhole" if blackhole else "active",
             "type": "static",
         }
@@ -154,19 +178,19 @@ class TransitGatewayRouteTableBackend:
 
     def delete_transit_gateway_route(
         self, transit_gateway_route_table_id: str, destination_cidr_block: str
-    ) -> TransitGatewayRouteTable:
+    ) -> dict[str, Optional[str]]:
         transit_gateways_route_table = self.transit_gateways_route_tables[
             transit_gateway_route_table_id
         ]
         transit_gateways_route_table.routes[destination_cidr_block]["state"] = "deleted"
-        return transit_gateways_route_table
+        return transit_gateways_route_table.routes.pop(destination_cidr_block)
 
     def search_transit_gateway_routes(
         self,
         transit_gateway_route_table_id: str,
         filters: Any,
         max_results: Optional[int] = None,
-    ) -> Dict[str, Dict[str, Optional[str]]]:
+    ) -> list[Dict[str, Optional[str]]]:
         """
         The following filters are currently supported: type, state, route-search.exact-match
         """
@@ -174,7 +198,7 @@ class TransitGatewayRouteTableBackend:
             transit_gateway_route_table_id
         )
         if not transit_gateway_route_table:
-            return {}
+            return []
 
         attr_pairs = (
             ("type", "type"),
@@ -192,41 +216,35 @@ class TransitGatewayRouteTableBackend:
                         break
         if max_results:
             routes = routes[: int(max_results)]  # type: ignore
-        return routes
+        return list(routes.values())
 
     def set_route_table_association(
         self, transit_gateway_attachment_id: str, transit_gateway_route_table_id: str
     ) -> None:
-        self.transit_gateways_route_tables[
-            transit_gateway_route_table_id
-        ].route_table_association = {
-            "resourceId": self.transit_gateway_attachments[  # type: ignore[attr-defined]
-                transit_gateway_attachment_id
-            ].resource_id,
-            "resourceType": self.transit_gateway_attachments[  # type: ignore[attr-defined]
-                transit_gateway_attachment_id
-            ].resource_type,
-            "state": "associated",
-            "transitGatewayAttachmentId": transit_gateway_attachment_id,
-        }
+        table = self.transit_gateways_route_tables[transit_gateway_route_table_id]
+        attachment = self.transit_gateway_attachments[transit_gateway_attachment_id]  # type: ignore[attr-defined]
+        table.route_table_association.resourceId = attachment.resource_id
+        table.route_table_association.resourceType = attachment.resource_type
+        table.route_table_association.state = "associated"
+        table.route_table_association.transitGatewayAttachmentId = (
+            transit_gateway_attachment_id
+        )
 
     def unset_route_table_association(self, tgw_rt_id: str) -> None:
         tgw_rt = self.transit_gateways_route_tables[tgw_rt_id]
-        tgw_rt.route_table_association = {}
+        tgw_rt.route_table_association.clear()
 
     def set_route_table_propagation(
         self, transit_gateway_attachment_id: str, transit_gateway_route_table_id: str
     ) -> None:
         route_table = self.transit_gateways_route_tables[transit_gateway_route_table_id]
         attchment = self.transit_gateway_attachments[transit_gateway_attachment_id]  # type: ignore[attr-defined]
-        route_table.route_table_propagation.append(
-            {
-                "resourceId": attchment.resource_id,
-                "resourceType": attchment.resource_type,
-                "state": "enabled",
-                "transitGatewayAttachmentId": transit_gateway_attachment_id,
-            }
-        )
+        propagation = RouteTablePropagation()
+        propagation.resourceId = attchment.resource_id
+        propagation.resourceType = attchment.resource_type
+        propagation.state = "enabled"
+        propagation.transitGatewayAttachmentId = transit_gateway_attachment_id
+        route_table.route_table_propagation.append(propagation)
 
     def disable_route_table_propagation(
         self, transit_gateway_attachment_id: str, transit_gateway_route_table_id: str
@@ -235,12 +253,12 @@ class TransitGatewayRouteTableBackend:
         route_table.route_table_propagation = [
             prop
             for prop in route_table.route_table_propagation
-            if prop["transitGatewayAttachmentId"] != transit_gateway_attachment_id
+            if prop.transitGatewayAttachmentId != transit_gateway_attachment_id
         ]
 
     def get_transit_gateway_route_table_associations(
         self, transit_gateway_route_table_id: List[str], filters: Any = None
-    ) -> List[TransitGatewayRouteTable]:
+    ) -> list[RouteTableAssociation]:
         transit_gateway_route_tables = list(self.transit_gateways_route_tables.values())
 
         if transit_gateway_route_tables:
@@ -251,23 +269,24 @@ class TransitGatewayRouteTableBackend:
             ]
 
         attr_pairs = (
-            ("resource-id", "route_table_association", "resourceId"),
-            ("resource-type", "route_table_association", "resourceType"),
+            ("resource-id", "resourceId"),
+            ("resource-type", "resourceType"),
             (
                 "transit-gateway-attachment-id",
-                "route_table_association",
                 "transitGatewayAttachmentId",
             ),
         )
 
-        result = transit_gateway_route_tables
+        result = [
+            table.route_table_association for table in transit_gateway_route_tables
+        ]
         if filters:
-            result = filter_resources(transit_gateway_route_tables, filters, attr_pairs)
+            result = filter_resources(result, filters, attr_pairs)
         return result
 
     def get_transit_gateway_route_table_propagations(
         self, transit_gateway_route_table_id: str, filters: Any = None
-    ) -> List[TransitGatewayRouteTable]:
+    ) -> List[RouteTablePropagation]:
         transit_gateway_route_tables = list(self.transit_gateways_route_tables.values())
 
         if transit_gateway_route_tables:
@@ -278,18 +297,21 @@ class TransitGatewayRouteTableBackend:
             ]
 
         attr_pairs = (
-            ("resource-id", "route_table_propagation", "resourceId"),
-            ("resource-type", "route_table_propagation", "resourceType"),
+            ("resource-id", "resourceId"),
+            ("resource-type", "resourceType"),
             (
                 "transit-gateway-attachment-id",
-                "route_table_propagation",
                 "transitGatewayAttachmentId",
             ),
         )
 
-        result = transit_gateway_route_tables
+        result = list(
+            itertools.chain.from_iterable(
+                table.route_table_propagation for table in transit_gateway_route_tables
+            )
+        )
         if filters:
-            result = filter_resources(transit_gateway_route_tables, filters, attr_pairs)
+            result = filter_resources(result, filters, attr_pairs)
         return result
 
     def associate_transit_gateway_route_table(
