@@ -1,15 +1,19 @@
-from moto.core.responses import BaseResponse
+from ._base_response import EC2BaseResponse
 
 
-class AvailabilityZonesAndRegions(BaseResponse):
-    def describe_availability_zones(self):
+class AvailabilityZonesAndRegions(EC2BaseResponse):
+    def describe_availability_zones(self) -> str:
         self.error_on_dryrun()
         filters = self._filters_from_querystring()
-        zones = self.ec2_backend.describe_availability_zones(filters)
+        zone_names = self._get_multi_param("ZoneName")
+        zone_ids = self._get_multi_param("ZoneId")
+        zones = self.ec2_backend.describe_availability_zones(
+            filters, zone_names=zone_names, zone_ids=zone_ids
+        )
         template = self.response_template(DESCRIBE_ZONES_RESPONSE)
         return template.render(zones=zones)
 
-    def describe_regions(self):
+    def describe_regions(self) -> str:
         self.error_on_dryrun()
         region_names = self._get_multi_param("RegionName")
         regions = self.ec2_backend.describe_regions(region_names)
