@@ -140,19 +140,17 @@ class SecurityGroups(EC2BaseResponse):
         self.error_on_dryrun()
 
         for kwargs in self._process_rules_from_querystring():
-            rule, group = self.ec2_backend.authorize_security_group_egress(**kwargs)
-        self.ec2_backend.sg_old_egress_ruls[group.id] = group.egress_rules.copy()
+            rules, group = self.ec2_backend.authorize_security_group_egress(**kwargs)
         template = self.response_template(AUTHORIZE_SECURITY_GROUP_EGRESS_RESPONSE)
-        return template.render(rule=rule, group=group)
+        return template.render(rules=rules, group=group)
 
     def authorize_security_group_ingress(self) -> str:
         self.error_on_dryrun()
 
         for kwargs in self._process_rules_from_querystring():
-            rule, group = self.ec2_backend.authorize_security_group_ingress(**kwargs)
-        self.ec2_backend.sg_old_ingress_ruls[group.id] = group.ingress_rules.copy()
+            rules, group = self.ec2_backend.authorize_security_group_ingress(**kwargs)
         template = self.response_template(AUTHORIZE_SECURITY_GROUP_INGRESS_RESPONSE)
-        return template.render(rule=rule, group=group)
+        return template.render(rules=rules, group=group)
 
     def create_security_group(self) -> str:
         name = self._get_param("GroupName")
@@ -165,9 +163,6 @@ class SecurityGroups(EC2BaseResponse):
         group = self.ec2_backend.create_security_group(
             name, description, vpc_id=vpc_id, tags=tags
         )
-        if group:
-            self.ec2_backend.sg_old_ingress_ruls[group.id] = group.ingress_rules.copy()
-            self.ec2_backend.sg_old_egress_ruls[group.id] = group.egress_rules.copy()
         template = self.response_template(CREATE_SECURITY_GROUP_RESPONSE)
         return template.render(group=group)
 
@@ -201,20 +196,10 @@ class SecurityGroups(EC2BaseResponse):
         return template.render(groups=groups)
 
     def describe_security_group_rules(self) -> str:
-        group_id = self._get_param("GroupId")
-        sg_rule_ids = self._get_param("SecurityGroupRuleId.1")
-        filters = self._filters_from_querystring()
-
         self.error_on_dryrun()
-
-        # if sg rule ids are not None then wrap in a list
-        # as expected by ec2_backend.describe_security_group_rules
-        if sg_rule_ids:
-            sg_rule_ids = [sg_rule_ids]
-
-        rules = self.ec2_backend.describe_security_group_rules(
-            group_id, sg_rule_ids, filters
-        )
+        sg_rule_ids = self._get_multi_param("SecurityGroupRuleId")
+        filters = self._filters_from_querystring()
+        rules = self.ec2_backend.describe_security_group_rules(sg_rule_ids, filters)
         template = self.response_template(DESCRIBE_SECURITY_GROUP_RULES_RESPONSE)
         return template.render(rules=rules)
 
@@ -236,24 +221,31 @@ class SecurityGroups(EC2BaseResponse):
             self.ec2_backend.revoke_security_group_ingress(**args)
         return REVOKE_SECURITY_GROUP_INGRESS_RESPONSE
 
+    def modify_security_group_rules(self) -> str:
+        self.error_on_dryrun()
+
+        rules = {}
+        security_group_rules_param = self._get_params()["SecurityGroupRule"]
+        for idx, sgr in security_group_rules_param.items():
+            rules[sgr["SecurityGroupRuleId"]] = sgr["SecurityGroupRule"]
+
+        group_id = self._get_param("GroupId")
+        self.ec2_backend.modify_security_group_rules(group_id, rules)
+
+        return MODIFY_SECURITY_GROUP_RULES_RESPONSE
+
     def update_security_group_rule_descriptions_ingress(self) -> str:
         for args in self._process_rules_from_querystring():
             # we don't need this parameter to revoke
             del args["sgrule_tags"]
-            group = self.ec2_backend.update_security_group_rule_descriptions_ingress(
-                **args
-            )
-        self.ec2_backend.sg_old_ingress_ruls[group.id] = group.ingress_rules.copy()
+            self.ec2_backend.update_security_group_rule_descriptions_ingress(**args)
         return UPDATE_SECURITY_GROUP_RULE_DESCRIPTIONS_INGRESS
 
     def update_security_group_rule_descriptions_egress(self) -> str:
         for args in self._process_rules_from_querystring():
             # we don't need this parameter to revoke
             del args["sgrule_tags"]
-            group = self.ec2_backend.update_security_group_rule_descriptions_egress(
-                **args
-            )
-        self.ec2_backend.sg_old_egress_ruls[group.id] = group.egress_rules.copy()
+            self.ec2_backend.update_security_group_rule_descriptions_egress(**args)
         return UPDATE_SECURITY_GROUP_RULE_DESCRIPTIONS_EGRESS
 
 
@@ -261,6 +253,7 @@ CREATE_SECURITY_GROUP_RESPONSE = """<CreateSecurityGroupResponse xmlns="http://e
    <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
    <return>true</return>
    <groupId>{{ group.id }}</groupId>
+   <securityGroupArn>{{ group.arn }}</securityGroupArn>
    <tagSet>
     {% for tag in group.get_tags() %}
         <item>
@@ -275,29 +268,40 @@ DESCRIBE_SECURITY_GROUP_RULES_RESPONSE = """
 <DescribeSecurityGroupRulesResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
   <requestId>{{ request_id }}</requestId>
   <securityGroupRuleSet>
-        {% for rule in rules %}
-          {% for ip_range in rule.ip_ranges %}
-            <item>
-                <fromPort>{{ rule.from_port if rule.from_port is not none else -1 }}</fromPort>
-                <toPort>{{ rule.to_port if rule.to_port is not none else -1 }}</toPort>
-                <cidrIpv4>{{ ip_range['CidrIp'] }}</cidrIpv4>
-                <ipProtocol>{{ rule.ip_protocol }}</ipProtocol>
-                <groupId>{{ rule.group_id }}</groupId>
-                <groupOwnerId>{{ rule.owner_id }}</groupOwnerId>
-                <description>{{ ip_range['Description'] }}</description>
-                <isEgress>{{ 'true' if rule.is_egress else 'false' }}</isEgress>
-                <securityGroupRuleId>{{ rule.id }}</securityGroupRuleId>
-                <tagSet>
-                {% for tag in rule.get_tags() %}
-                    <item>
-                      <key>{{ tag.key }}</key>
-                      <value>{{ tag.value }}</value>
-                    </item>
-                {% endfor %}
-                </tagSet> 
-            </item>
-          {% endfor %}
-        {% endfor %}
+    {% for rule in rules %}
+        <item>
+            <ipProtocol>{{ rule.ip_protocol }}</ipProtocol>
+            <groupId>{{ rule.group_id }}</groupId>
+            <groupOwnerId>{{ rule.owner_id }}</groupOwnerId>
+            <fromPort>{{ rule.from_port if rule.from_port is not none else -1 }}</fromPort>
+            <toPort>{{ rule.to_port if rule.to_port is not none else -1 }}</toPort>
+            <isEgress>{{ 'true' if rule.is_egress else 'false' }}</isEgress>
+            <securityGroupRuleId>{{ rule.id }}</securityGroupRuleId>
+            {% if rule.ip_range %}
+              {% if rule.ip_range['CidrIp'] %}<cidrIpv4>{{ rule.ip_range['CidrIp'] }}</cidrIpv4>{% endif %}
+              {% if rule.ip_range['CidrIpv6'] %}<cidrIpv6>{{ rule.ip_range['CidrIpv6'] }}</cidrIpv6>{% endif %}
+              {% if rule.ip_range['Description'] %}<description>{{ rule.ip_range['Description'] }}</description>{% endif %}
+            {% endif %}
+            {% if rule.source_group %}
+              <referencedGroupInfo>
+                <groupId>{{ rule.source_group['GroupId'] }}</groupId><userId>{{ rule.source_group['OwnerId'] }}</userId>
+              </referencedGroupInfo>
+              {% if rule.source_group['Description'] %}<description>{{ rule.source_group['Description'] }}</description>{% endif %}
+            {% endif %}
+            {% if rule.prefix_list_id %}
+              <prefixListId>{{ rule.prefix_list_id['PrefixListId'] }}</prefixListId>
+              {% if rule.prefix_list_id['Description'] %}<description>{{ rule.prefix_list_id['Description'] }}</description>{% endif %}
+            {% endif %}
+            <tagSet>
+            {% for tag in rule.get_tags() %}
+                <item>
+                  <key>{{ tag.key }}</key>
+                  <value>{{ tag.value }}</value>
+                </item>
+            {% endfor %}
+            </tagSet> 
+        </item>
+    {% endfor %}
   </securityGroupRuleSet>
 </DescribeSecurityGroupRulesResponse>"""
 
@@ -315,11 +319,12 @@ DESCRIBE_SECURITY_GROUPS_RESPONSE = """<DescribeSecurityGroupsResponse xmlns="ht
              <groupId>{{ group.id }}</groupId>
              <groupName>{{ group.name }}</groupName>
              <groupDescription>{{ group.description }}</groupDescription>
+             <securityGroupArn>{{ group.arn }}</securityGroupArn>
              {% if group.vpc_id %}
              <vpcId>{{ group.vpc_id }}</vpcId>
              {% endif %}
              <ipPermissions>
-               {% for rule in group.ingress_rules %}
+               {% for rule in group.flattened_ingress_rules %}
                     <item>
                        <ipProtocol>{{ rule.ip_protocol }}</ipProtocol>
                        {% if rule.from_port is not none %}
@@ -384,7 +389,7 @@ DESCRIBE_SECURITY_GROUPS_RESPONSE = """<DescribeSecurityGroupsResponse xmlns="ht
                 {% endfor %}
              </ipPermissions>
              <ipPermissionsEgress>
-               {% for rule in group.egress_rules %}
+               {% for rule in group.flattened_egress_rules %}
                     <item>
                        <ipProtocol>{{ rule.ip_protocol }}</ipProtocol>
                        {% if rule.from_port is not none %}
@@ -465,15 +470,35 @@ AUTHORIZE_SECURITY_GROUP_INGRESS_RESPONSE = """<AuthorizeSecurityGroupIngressRes
     <requestId>b1f67202-c2c2-4ba4-8464-c8b1d8f5af7a</requestId>
     <return>true</return>
     <securityGroupRuleSet>
-    {% for item in rule.ip_ranges %}
+    {% for rule in rules %}
         <item>
-            {% if item.CidrIp %}
-            <cidrIpv4>{{ item.CidrIp }}</cidrIpv4>
+            {% if rule.ip_range %}
+                {% if rule.ip_range.CidrIp %}
+                <cidrIpv4>{{ rule.ip_range.CidrIp }}</cidrIpv4>
+                {% endif %}
+                {% if rule.ip_range.CidrIpv6 %}
+                <cidrIpv6>{{ rule.ip_range.CidrIpv6 }}</cidrIpv6>
+                {% endif %}
+                <description>{{ rule.ip_range.Description or '' }}</description>
             {% endif %}
-            {% if item.CidrIpv6 %}
-            <cidrIpv6>{{ item.CidrIpv6 }}</cidrIpv6>
+            {% if rule.prefix_list_id %}
+                <prefixListId>{{ rule.prefix_list_id.PrefixListId }}</prefixListId>
+                <description>{{ rule.prefix_list_id.Description or '' }}</description>
+            {% endif %}
+            {% if rule.source_group %}
+                <referencedGroupInfo>
+                    {% if rule.source_group.OwnerId and rule.source_group.OwnerId != "" %}
+                    <userId>{{ rule.source_group.OwnerId }}</userId>
+                    {% endif %}
+                    {% if rule.source_group.GroupId and rule.source_group.GroupId != "" %}
+                    <groupId>{{ rule.source_group.GroupId }}</groupId>
+                    {% endif %}
+                    {% if rule.source_group.VpcId and rule.source_group.VpcId != "" %}
+                    <vpcId>{{ rule.source_group.VpcId }}</vpcId>
+                    {% endif %}
+                </referencedGroupInfo>
+                <description>{{ rule.source_group.Description or '' }}</description>
             {% endif %}
-            <description>{{ item.Description or '' }}</description>
             {% if rule.from_port is not none %}
             <fromPort>{{ rule.from_port }}</fromPort>
             {% endif %}
@@ -495,52 +520,6 @@ AUTHORIZE_SECURITY_GROUP_INGRESS_RESPONSE = """<AuthorizeSecurityGroupIngressRes
             </tagSet> 
         </item>
     {% endfor %}
-    {% for item in rule.prefix_list_ids %}
-        <item>
-            <prefixListId>{{ item.PrefixListId }}</prefixListId>
-            <description>{{ item.Description or '' }}</description>
-            {% if rule.from_port is not none %}
-            <fromPort>{{ rule.from_port }}</fromPort>
-            {% endif %}
-            <groupId>{{ group.id }}</groupId>
-            <groupOwnerId>{{ rule.owner_id }}</groupOwnerId>
-            <ipProtocol>{{ rule.ip_protocol }}</ipProtocol>
-            <isEgress>false</isEgress>
-            <securityGroupRuleId>{{ rule.id }}</securityGroupRuleId>
-            {% if rule.to_port is not none %}
-            <toPort>{{ rule.to_port }}</toPort>
-            {% endif %}
-        </item>
-    {% endfor %}
-    {% for item in rule.source_groups %}
-        <item>
-            {% if item.Description and item.Description != "" %}
-            <description>{{ item.Description }}</description>
-            {% endif %}
-            {% if rule.from_port is not none %}
-            <fromPort>{{ rule.from_port }}</fromPort>
-            {% endif %}
-            <groupId>{{ group.id }}</groupId>
-            <groupOwnerId>{{ rule.owner_id }}</groupOwnerId>
-            <ipProtocol>{{ rule.ip_protocol }}</ipProtocol>
-            <isEgress>true</isEgress>
-            <securityGroupRuleId>{{ rule.id }}</securityGroupRuleId>
-            {% if rule.to_port is not none %}
-            <toPort>{{ rule.to_port }}</toPort>
-            {% endif %}
-            <referencedGroupInfo>
-                {% if item.OwnerId and item.OwnerId != "" %}
-                <userId>{{ item.OwnerId }}</userId>
-                {% endif %}
-                {% if item.GroupId and item.GroupId != "" %}
-                <groupId>{{ item.GroupId }}</groupId>
-                {% endif %}
-                {% if item.VpcId and item.VpcId != "" %}
-                <vpcId>{{ item.VpcId }}</vpcId>
-                {% endif %}
-            </referencedGroupInfo>
-        </item>
-    {% endfor %}
     </securityGroupRuleSet>
 </AuthorizeSecurityGroupIngressResponse>"""
 
@@ -553,15 +532,35 @@ AUTHORIZE_SECURITY_GROUP_EGRESS_RESPONSE = """<AuthorizeSecurityGroupEgressRespo
     <requestId>b1f67202-c2c2-4ba4-8464-c8b1d8f5af7a</requestId>
     <return>true</return>
     <securityGroupRuleSet>
-    {% for item in rule.ip_ranges %}
+    {% for rule in rules %}
         <item>
-            {% if item.CidrIp %}
-            <cidrIpv4>{{ item.CidrIp }}</cidrIpv4>
+            {% if rule.ip_range %}
+                {% if rule.ip_range.CidrIp %}
+                <cidrIpv4>{{ rule.ip_range.CidrIp }}</cidrIpv4>
+                {% endif %}
+                {% if rule.ip_range.CidrIpv6 %}
+                <cidrIpv6>{{ rule.ip_range.CidrIpv6 }}</cidrIpv6>
+                {% endif %}
+                <description>{{ rule.ip_range.Description or '' }}</description>
             {% endif %}
-            {% if item.CidrIpv6 %}
-            <cidrIpv6>{{ item.CidrIpv6 }}</cidrIpv6>
+            {% if rule.prefix_list_id %}
+                <prefixListId>{{ rule.prefix_list_id.PrefixListId }}</prefixListId>
+                <description>{{ rule.prefix_list_id.Description or '' }}</description>
+            {% endif %}
+            {% if rule.source_group %}
+                <referencedGroupInfo>
+                    {% if rule.source_group.OwnerId and rule.source_group.OwnerId != "" %}
+                    <userId>{{ rule.source_group.OwnerId }}</userId>
+                    {% endif %}
+                    {% if rule.source_group.GroupId and rule.source_group.GroupId != "" %}
+                    <groupId>{{ rule.source_group.GroupId }}</groupId>
+                    {% endif %}
+                    {% if rule.source_group.VpcId and rule.source_group.VpcId != "" %}
+                    <vpcId>{{ rule.source_group.VpcId }}</vpcId>
+                    {% endif %}
+                </referencedGroupInfo>
+                <description>{{ rule.source_group.Description or '' }}</description>
             {% endif %}
-            <description>{{ item.Description or '' }}</description>
             {% if rule.from_port is not none %}
             <fromPort>{{ rule.from_port }}</fromPort>
             {% endif %}
@@ -583,52 +582,6 @@ AUTHORIZE_SECURITY_GROUP_EGRESS_RESPONSE = """<AuthorizeSecurityGroupEgressRespo
             </tagSet> 
         </item>
     {% endfor %}
-    {% for item in rule.prefix_list_ids %}
-        <item>
-            <prefixListId>{{ item.PrefixListId }}</prefixListId>
-            <description>{{ item.Description or '' }}</description>
-            {% if rule.from_port is not none %}
-            <fromPort>{{ rule.from_port }}</fromPort>
-            {% endif %}
-            <groupId>{{ group.id }}</groupId>
-            <groupOwnerId>{{ rule.owner_id }}</groupOwnerId>
-            <ipProtocol>{{ rule.ip_protocol }}</ipProtocol>
-            <isEgress>true</isEgress>
-            <securityGroupRuleId>{{ rule.id }}</securityGroupRuleId>
-            {% if rule.to_port is not none %}
-            <toPort>{{ rule.to_port }}</toPort>
-            {% endif %}
-        </item>
-    {% endfor %}
-    {% for item in rule.source_groups %}
-        <item>
-            {% if item.Description and item.Description != "" %}
-            <description>{{ item.Description }}</description>
-            {% endif %}
-            {% if rule.from_port is not none %}
-            <fromPort>{{ rule.from_port }}</fromPort>
-            {% endif %}
-            <groupId>{{ group.id }}</groupId>
-            <groupOwnerId>{{ rule.owner_id }}</groupOwnerId>
-            <ipProtocol>{{ rule.ip_protocol }}</ipProtocol>
-            <isEgress>true</isEgress>
-            <securityGroupRuleId>{{ rule.id }}</securityGroupRuleId>
-            {% if rule.to_port is not none %}
-            <toPort>{{ rule.to_port }}</toPort>
-            {% endif %}
-            <referencedGroupInfo>
-                {% if item.OwnerId and item.OwnerId != "" %}
-                <userId>{{ item.OwnerId }}</userId>
-                {% endif %}
-                {% if item.GroupId and item.GroupId != "" %}
-                <groupId>{{ item.GroupId }}</groupId>
-                {% endif %}
-                {% if item.VpcId and item.VpcId != "" %}
-                <vpcId>{{ item.VpcId }}</vpcId>
-                {% endif %}
-            </referencedGroupInfo>
-        </item>
-    {% endfor %}
     </securityGroupRuleSet>
 </AuthorizeSecurityGroupEgressResponse>"""
 
@@ -637,6 +590,13 @@ REVOKE_SECURITY_GROUP_EGRESS_RESPONSE = """<RevokeSecurityGroupEgressResponse xm
   <return>true</return>
 </RevokeSecurityGroupEgressResponse>"""
 
+MODIFY_SECURITY_GROUP_RULES_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
+<ModifySecurityGroupRulesResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
+  <requestId>04d8f970-9213-41fa-81d2-50825EXAMPLE</requestId>
+  <return>true</return>
+</ModifySecurityGroupRulesResponse>
+"""
+
 UPDATE_SECURITY_GROUP_RULE_DESCRIPTIONS_INGRESS = """<UpdateSecurityGroupRuleDescriptionsIngressResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
   <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
   <return>true</return>
