@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import hashlib
 import json
 import re
@@ -42,31 +44,7 @@ EcrRepositoryArn = namedtuple(
 )
 
 
-class BaseObject(BaseModel):
-    def camelCase(self, key: str) -> str:
-        words = []
-        for i, word in enumerate(key.split("_")):
-            if i > 0:
-                words.append(word.title())
-            else:
-                words.append(word)
-        return "".join(words)
-
-    def gen_response_object(self) -> Dict[str, Any]:
-        response_object = dict()
-        for key, value in self.__dict__.items():
-            if "_" in key:
-                response_object[self.camelCase(key)] = value
-            else:
-                response_object[key] = value
-        return response_object
-
-    @property
-    def response_object(self) -> Dict[str, Any]:  # type: ignore[misc]
-        return self.gen_response_object()
-
-
-class Repository(BaseObject, CloudFormationModel):
+class Repository(CloudFormationModel, BaseModel):
     def __init__(
         self,
         account_id: str,
@@ -115,7 +93,7 @@ class Repository(BaseObject, CloudFormationModel):
 
     def _get_image(
         self, image_tag: Optional[str], image_digest: Optional[str]
-    ) -> "Image":
+    ) -> Image:
         # you can either search for one or both
         image = next(
             (
@@ -144,20 +122,6 @@ class Repository(BaseObject, CloudFormationModel):
     def physical_resource_id(self) -> str:
         return self.name
 
-    @property
-    def response_object(self) -> Dict[str, Any]:  # type: ignore[misc]
-        response_object = self.gen_response_object()
-
-        response_object["registryId"] = self.registry_id
-        response_object["repositoryArn"] = self.arn
-        response_object["repositoryName"] = self.name
-        response_object["repositoryUri"] = self.uri
-        response_object["createdAt"] = iso_8601_datetime_without_milliseconds(
-            self.created_at
-        )
-        del response_object["arn"], response_object["name"], response_object["images"]
-        return response_object
-
     def update(
         self,
         image_scan_config: Optional[Dict[str, Any]] = None,
@@ -259,7 +223,7 @@ class Repository(BaseObject, CloudFormationModel):
             )
 
 
-class Image(BaseObject):
+class Image(BaseModel):
     def __init__(
         self,
         account_id: str,
@@ -273,31 +237,49 @@ class Image(BaseObject):
         self.image_tag = tag
         self.image_tags = [tag] if tag is not None else []
         self.image_manifest = manifest
-        self.image_manifest_mediatype = image_manifest_mediatype
-        self.repository = repository
+        self.image_manifest_media_type = image_manifest_mediatype
+        self.repository_name = repository
         self.registry_id = registry_id or account_id
-        self.image_digest = digest
+        self._image_digest = digest
         self.image_pushed_at = int(datetime.now(timezone.utc).timestamp())
         self.last_scan: Optional[datetime] = None
 
+        self.scan_finding_results_queue: List[Any] = []
+        self.scan_finding_results: Dict[str, Any] = {}
+
+    @property
+    def image_digest(self) -> str:
+        return self.get_image_digest()
+
+    @property
+    def image_id(self) -> dict[str, str]:
+        return {
+            "imageTag": self.image_tag,
+            "imageDigest": self.get_image_digest(),
+        }
+
+    @property
+    def image_size_in_bytes(self) -> int | None:
+        return self.get_image_size_in_bytes()
+
     def _create_digest(self) -> None:
         image_manifest = json.loads(self.image_manifest)
         if "layers" in image_manifest:
             layer_digests = [layer["digest"] for layer in image_manifest["layers"]]
-            self.image_digest = (
+            self._image_digest = (
                 "sha256:"
                 + hashlib.sha256("".join(layer_digests).encode("utf-8")).hexdigest()
             )
         else:
             random_sha = hashlib.sha256(
-                f"{random.randint(0,100)}".encode("utf-8")
+                f"{random.randint(0, 100)}".encode("utf-8")
             ).hexdigest()
-            self.image_digest = f"sha256:{random_sha}"
+            self._image_digest = f"sha256:{random_sha}"
 
     def get_image_digest(self) -> str:
-        if not self.image_digest:
+        if not self._image_digest:
             self._create_digest()
-        return self.image_digest  # type: ignore[return-value]
+        return self._image_digest  # type: ignore[return-value]
 
     def get_image_size_in_bytes(self) -> Optional[int]:
         image_manifest = json.loads(self.image_manifest)
@@ -323,70 +305,6 @@ class Image(BaseObject):
         if tag not in self.image_tags and tag is not None:
             self.image_tags.append(tag)
 
-    @property
-    def response_object(self) -> Dict[str, Any]:  # type: ignore[misc]
-        response_object = self.gen_response_object()
-        response_object["imageId"] = {}
-        response_object["imageId"]["imageTag"] = self.image_tag
-        response_object["imageId"]["imageDigest"] = self.get_image_digest()
-        response_object["imageManifest"] = self.image_manifest
-        response_object["imageManifestMediaType"] = self.image_manifest_mediatype
-        response_object["repositoryName"] = self.repository
-        response_object["registryId"] = self.registry_id
-        return {
-            k: v for k, v in response_object.items() if v is not None and v != [None]
-        }
-
-    @property
-    def response_list_object(self) -> Dict[str, Any]:  # type: ignore[misc]
-        response_object = self.gen_response_object()
-        response_object["imageTag"] = self.image_tag
-        response_object["imageDigest"] = self.get_image_digest()
-        return {
-            k: v for k, v in response_object.items() if v is not None and v != [None]
-        }
-
-    @property
-    def response_describe_object(self) -> Dict[str, Any]:  # type: ignore[misc]
-        response_object = self.gen_response_object()
-        response_object["imageTags"] = self.image_tags
-        response_object["imageDigest"] = self.get_image_digest()
-        response_object["imageManifest"] = self.image_manifest
-        response_object["imageManifestMediaType"] = self.image_manifest_mediatype
-        response_object["repositoryName"] = self.repository
-        response_object["registryId"] = self.registry_id
-        response_object["imageSizeInBytes"] = self.get_image_size_in_bytes()
-        response_object["imagePushedAt"] = self.image_pushed_at
-        return {k: v for k, v in response_object.items() if v is not None and v != []}
-
-    @property
-    def response_batch_get_image(self) -> Dict[str, Any]:  # type: ignore[misc]
-        response_object = {
-            "imageId": {
-                "imageTag": self.image_tag,
-                "imageDigest": self.get_image_digest(),
-            },
-            "imageManifest": self.image_manifest,
-            "repositoryName": self.repository,
-            "registryId": self.registry_id,
-        }
-        return {
-            k: v
-            for k, v in response_object.items()
-            if v is not None and v != [None]  # type: ignore
-        }
-
-    @property
-    def response_batch_delete_image(self) -> Dict[str, Any]:  # type: ignore[misc]
-        response_object = {}
-        response_object["imageDigest"] = self.get_image_digest()
-        response_object["imageTag"] = self.image_tag
-        return {
-            k: v
-            for k, v in response_object.items()
-            if v is not None and v != [None]  # type: ignore
-        }
-
 
 class ECRBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
@@ -401,6 +319,8 @@ class ECRBackend(BaseBackend):
         self.registry_scanning_configuration_update_lock = threading.RLock()
         self.tagger = TaggingService(tag_name="tags")
 
+        self.scan_finding_results: list[dict[str, Any]] = []
+
     @staticmethod
     def default_vpc_endpoint_service(  # type: ignore[misc]
         service_region: str, zones: List[str]
@@ -451,7 +371,7 @@ class ECRBackend(BaseBackend):
         self,
         registry_id: Optional[str] = None,
         repository_names: Optional[List[str]] = None,
-    ) -> List[Dict[str, Any]]:
+    ) -> List[Repository]:
         """
         maxResults and nextToken not implemented
         """
@@ -473,7 +393,7 @@ class ECRBackend(BaseBackend):
             if repository_names:
                 if repository.name not in repository_names:
                     continue
-            repositories.append(repository.response_object)
+            repositories.append(repository)
         return repositories
 
     def create_repository(
@@ -604,14 +524,14 @@ class ECRBackend(BaseBackend):
         else:
             if "mediaType" not in parsed_image_manifest:
                 raise InvalidParameterException(
-                    message="image manifest mediatype not provided in manifest or parameter"
+                    "image manifest mediatype not provided in manifest or parameter"
                 )
             else:
                 image_manifest_mediatype = parsed_image_manifest["mediaType"]
 
         existing_images_with_matching_manifest = list(
             filter(
-                lambda x: x.response_object["imageManifest"] == image_manifest,
+                lambda x: x.image_manifest == image_manifest,
                 repository.images,
             )
         )
@@ -701,7 +621,7 @@ class ECRBackend(BaseBackend):
                     "imageTag" in image_id and image_id["imageTag"] in image.image_tags
                 ):
                     found = True
-                    response["images"].append(image.response_batch_get_image)
+                    response["images"].append(image)
 
             if not found:
                 response["failures"].append(
@@ -732,6 +652,11 @@ class ECRBackend(BaseBackend):
                 msg='Missing required parameter in input: "imageIds"'
             )
 
+        class ImageId:
+            def __init__(self, img: Image):
+                self.image_digest = img.get_image_digest()
+                self.image_tag = img.image_tag
+
         response: Dict[str, Any] = {"imageIds": [], "failures": []}
 
         for image_id in image_ids:
@@ -771,9 +696,7 @@ class ECRBackend(BaseBackend):
                         image_found = True
                         for image_tag in reversed(image.image_tags):
                             repository.images[num].image_tag = image_tag
-                            response["imageIds"].append(
-                                image.response_batch_delete_image
-                            )
+                            response["imageIds"].append(ImageId(image))
                             repository.images[num].remove_tag(image_tag)
                         del repository.images[num]
 
@@ -785,7 +708,7 @@ class ECRBackend(BaseBackend):
                     image_found = True
                     for image_tag in reversed(image.image_tags):
                         repository.images[num].image_tag = image_tag
-                        response["imageIds"].append(image.response_batch_delete_image)
+                        response["imageIds"].append(ImageId(image))
                         repository.images[num].remove_tag(image_tag)
                     del repository.images[num]
 
@@ -795,7 +718,7 @@ class ECRBackend(BaseBackend):
                 ):
                     image_found = True
                     repository.images[num].image_tag = image_id["imageTag"]
-                    response["imageIds"].append(image.response_batch_delete_image)
+                    response["imageIds"].append(ImageId(image))
                     if len(image.image_tags) > 1:
                         repository.images[num].remove_tag(image_id["imageTag"])
                     else:
@@ -893,6 +816,8 @@ class ECRBackend(BaseBackend):
             iam_policy_document_validator._validate_resource_exist = lambda: None  # type: ignore
             # the repository policy can have the old version 2008-10-17
             iam_policy_document_validator._validate_version = lambda: None  # type: ignore
+            # ECR does not have uniqueness requirements on Sids
+            iam_policy_document_validator._validate_sid_uniqueness = lambda: None  # type: ignore
             iam_policy_document_validator.validate()
         except MalformedPolicyDocument:
             raise InvalidParameterException(
@@ -1066,6 +991,56 @@ class ECRBackend(BaseBackend):
     def describe_image_scan_findings(
         self, registry_id: str, repository_name: str, image_id: Dict[str, Any]
     ) -> Dict[str, Any]:
+        """
+        This operation will return a static result by default. It is possible to configure a custom result using the Moto API.
+
+        Here is some example code showing how this can be configured:
+
+        .. sourcecode:: python
+
+            # Dict with the exact response that you want to Moto to return
+            example_response = {
+                "imageScanFindings": {
+                    "enhancedFindings": [
+                    ],
+                    "findingSeverityCounts": {
+                        "MEDIUM": 1,
+                        "UNTRIAGED": 1
+                    }
+                },
+                "registryId": 000000000000,
+                "repositoryName": "reponame",
+                "imageId": {
+                    "imageTag": "latest"
+                },
+                "imageScanStatus": {
+                    "status": "COMPLETE",
+                    "description": "The scan was completed successfully."
+                }
+            }
+            findings = {
+                "results": [example_response],
+                # Specify a region - us-east-1 by default
+                "region": "us-west-1",
+            }
+            resp = requests.post(
+                "http://motoapi.amazonaws.com/moto-api/static/ecr/scan-finding-results",
+                json=findings,
+            )
+
+            ecr = boto3.client("ecr", region_name="us-west-1")
+            # Create an image and start a scan
+            # ...
+            # Return the findings for reponame:latest
+            findings = ecr.describe_image_scan_findings(
+                repositoryName="reponame", imageId={"imageTag": "latest"}
+            )
+            findings.pop("ResponseMetadata")
+            assert findings == example_response
+
+        Note that the repository-name and imageTag/imageDigest should be an exact match. If you call `describe_image_scan_findings` with a repository/imageTag that is not part of any of the custom results, Moto will return a static default response.
+
+        """
         repo = self._get_repository(repository_name, registry_id)
 
         image = repo._get_image(image_id.get("imageTag"), image_id.get("imageDigest"))
@@ -1080,7 +1055,7 @@ class ECRBackend(BaseBackend):
                 registry_id=repo.registry_id,
             )
 
-        return {
+        default_response = {
             "registryId": repo.registry_id,
             "repositoryName": repository_name,
             "imageId": {
@@ -1118,6 +1093,33 @@ class ECRBackend(BaseBackend):
             },
         }
 
+        # Process new results, and delegate any results for this particular image
+        for res in self.scan_finding_results.copy():
+            no_image = not res["imageId"].get("imageTag") and not res["imageId"].get(
+                "imageDigest"
+            )
+            if repo.name == res["repositoryName"] and (
+                no_image
+                or res["imageId"].get("imageTag") == image.image_tag
+                or res["imageId"].get("imageDigest") == image.image_digest
+            ):
+                image.scan_finding_results_queue.append(res)
+                self.scan_finding_results.remove(res)
+
+        # Unique key that identifies this invocation
+        key = f"{json.dumps(image_id)}"
+
+        # Get the latest result from the queue, and assign to our key
+        if image.scan_finding_results_queue and key not in image.scan_finding_results:
+            image.scan_finding_results[key] = image.scan_finding_results_queue.pop(0)
+        # Return the result if we've found any
+        if key in image.scan_finding_results:
+            return image.scan_finding_results[key]
+
+        # Default response. Should no longer be used by people, but is the legacy behaviour
+        # To remove in Moto v6.0 - users should configure their own expected response
+        return default_response
+
     def put_replication_configuration(
         self, replication_config: Dict[str, Any]
     ) -> Dict[str, Any]:
