@@ -1,15 +1,26 @@
-from typing import List, Optional, Dict, Any, Tuple
+from re import compile as re_compile
+from typing import Any, Dict, List, Optional
 
-from moto.core import BaseBackend, BackendDict, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.core.utils import utcnow
+from moto.utilities.paginator import paginate
+from moto.utilities.utils import get_partition
 
+from ..moto_api._internal import mock_random
 from .exceptions import (
-    UserAlreadyExists,
-    UserNotFound,
     CacheClusterAlreadyExists,
     CacheClusterNotFound,
+    CacheSubnetGroupAlreadyExists,
+    CacheSubnetGroupNotFound,
+    InvalidARNFault,
+    InvalidParameterCombinationException,
+    InvalidParameterValueException,
+    InvalidSubnet,
+    UserAlreadyExists,
+    UserNotFound,
 )
-from ..moto_api._internal import mock_random
+from .utils import PAGINATION_MODEL, AuthenticationTypes
 
 
 class User(BaseModel):
@@ -23,10 +34,12 @@ class User(BaseModel):
         engine: str,
         no_password_required: bool,
         passwords: Optional[List[str]] = None,
+        authentication_type: Optional[str] = None,
     ):
         self.id = user_id
         self.name = user_name
         self.engine = engine
+
         self.passwords = passwords or []
         self.access_string = access_string
         self.no_password_required = no_password_required
@@ -34,7 +47,8 @@ class User(BaseModel):
         self.minimum_engine_version = "6.0"
         self.usergroupids: List[str] = []
         self.region = region
-        self.arn = f"arn:aws:elasticache:{self.region}:{account_id}:user:{self.id}"
+        self.arn = f"arn:{get_partition(self.region)}:elasticache:{self.region}:{account_id}:user:{self.id}"
+        self.authentication_type = authentication_type
 
 
 class CacheCluster(BaseModel):
@@ -77,7 +91,6 @@ class CacheCluster(BaseModel):
     ):
         if tags is None:
             tags = []
-
         self.cache_cluster_id = cache_cluster_id
         self.az_mode = az_mode
         self.preferred_availability_zone = preferred_availability_zone
@@ -120,15 +133,101 @@ class CacheCluster(BaseModel):
         self.cache_cluster_create_time = utcnow()
         self.auth_token_last_modified_date = utcnow()
         self.cache_cluster_status = "available"
-        self.arn = f"arn:aws:elasticache:{region_name}:{account_id}:{cache_cluster_id}"
+        self.arn = f"arn:{get_partition(region_name)}:elasticache:{region_name}:{account_id}:cluster:{cache_cluster_id}"
         self.cache_node_id = str(mock_random.uuid4())
 
+    def get_tags(self) -> List[Dict[str, str]]:
+        return self.tags
+
+
+class CacheSubnetGroup(BaseModel):
+    def __init__(
+        self,
+        account_id: str,
+        region_name: str,
+        cache_subnet_group_name: str,
+        cache_subnet_group_description: str,
+        subnet_ids: List[str],
+        tags: Optional[List[Dict[str, str]]],
+    ):
+        if tags is None:
+            tags = []
+        self.cache_subnet_group_name = cache_subnet_group_name
+        self.cache_subnet_group_description = cache_subnet_group_description
+        self.subnet_ids = subnet_ids
+        self.tags = tags
+
+        # Only import ec2_backends if necessary
+        from moto.ec2.models import ec2_backends
+
+        ec2_backend = ec2_backends[account_id][region_name]
+        self.supported_network_types = []
+        self.subnets_responses = []
+        vpc_exists = False
+        try:
+            # Get VPC details from provided subnet IDs
+            subnets = ec2_backend.describe_subnets(subnet_ids=subnet_ids)
+            vpc_exists = True
+        except Exception as e:
+            # Should raise InvalidSubnet if subnet_ids are invalid
+            if "InvalidSubnet" in str(e):
+                for subnet_id in subnet_ids:
+                    subnet_response: Dict[str, Any] = {}
+                    subnet_response["subnet_id"] = subnet_id
+                    subnet_response["subnet_az"] = {"Name": "us-east-1a"}
+                    subnet_response["subnet_supported_network_types"] = ["ipv4"]
+                    self.subnets_responses.append(subnet_response)
+                vpcs = ["vpc-0123456789abcdef0"]
+                self.supported_network_types = ["ipv4"]
+
+        if vpc_exists:
+            vpcs = []
+            for subnet in subnets:
+                subnet_response = {}
+                vpcs.append(subnet.vpc_id)
+                subnet_response["subnet_id"] = subnet.id
+                subnet_response["subnet_az"] = subnet.availability_zone
+                subnet_response["subnet_supported_network_types"] = []
+                if subnet.vpc_id != vpcs[0]:
+                    raise InvalidSubnet(subnet_id=subnet.id)
+
+                # ipv6 native subnets only appends ipv6
+                # You can't mix ipv6 native subnets with other types of subnets
+                if subnet.ipv6_native:
+                    self.supported_network_types.append("ipv6")
+                    subnet_response["subnet_supported_network_types"].append("ipv6")
+
+                # ipv4 only and dual_stack subnets both append ipv4
+                elif subnet.cidr_block:
+                    self.supported_network_types.append("ipv4")
+                    subnet_response["subnet_supported_network_types"].append("ipv4")
+
+                if subnet.ipv6_cidr_block_associations and subnet.cidr_block:
+                    self.supported_network_types.append("dual_stack")
+                    subnet_response["subnet_supported_network_types"].append(
+                        "dual_stack"
+                    )
+
+                self.subnets_responses.append(subnet_response)
+
+            if self.supported_network_types:
+                self.supported_network_types = list(set(self.supported_network_types))
+
+        self.arn = f"arn:{get_partition(region_name)}:elasticache:{region_name}:{account_id}:subnetgroup:{cache_subnet_group_name}"
+        self.vpc_id = vpcs[0] if vpcs else None
+
+    def get_tags(self) -> List[Dict[str, str]]:
+        return self.tags
+
 
 class ElastiCacheBackend(BaseBackend):
     """Implementation of ElastiCache APIs."""
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
+        self.arn_regex = re_compile(
+            r"^arn:aws:elasticache:.*:[0-9]*:(cluster|snapshot|subnetgroup):.*$"
+        )
         self.users = dict()
         self.users["default"] = User(
             account_id=self.account_id,
@@ -140,44 +239,8 @@ class ElastiCacheBackend(BaseBackend):
             no_password_required=True,
         )
 
-        # Define the cache_clusters dictionary to detect duplicates
-        self.cache_clusters = dict()
-        self.cache_clusters["default"] = CacheCluster(
-            account_id=self.account_id,
-            region_name=self.region_name,
-            cache_cluster_id="default",
-            replication_group_id=None,
-            az_mode=None,
-            preferred_availability_zone=None,
-            num_cache_nodes=1,
-            cache_node_type=None,
-            engine="redis",
-            engine_version=None,
-            cache_parameter_group_name=None,
-            cache_subnet_group_name=None,
-            transit_encryption_enabled=True,
-            network_type=None,
-            ip_discovery=None,
-            snapshot_name=None,
-            preferred_maintenance_window=None,
-            port=6379,
-            notification_topic_arn=None,
-            auto_minor_version_upgrade=True,
-            snapshot_retention_limit=0,
-            snapshot_window=None,
-            auth_token=None,
-            outpost_mode=None,
-            preferred_outpost_arn=None,
-            preferred_availability_zones=[],
-            cache_security_group_names=[],
-            security_group_ids=[],
-            tags=[],
-            snapshot_arns=[],
-            preferred_outpost_arns=[],
-            log_delivery_configurations=[],
-            cache_node_ids_to_remove=[],
-            cache_node_ids_to_reboot=[],
-        )
+        self.cache_clusters: Dict[str, Any] = dict()
+        self.cache_subnet_groups: Dict[str, CacheSubnetGroup] = dict()
 
     def create_user(
         self,
@@ -187,9 +250,34 @@ class ElastiCacheBackend(BaseBackend):
         passwords: List[str],
         access_string: str,
         no_password_required: bool,
+        authentication_type: str,  # contain it to the str in the enums TODO
     ) -> User:
         if user_id in self.users:
             raise UserAlreadyExists
+
+        if authentication_type not in AuthenticationTypes._value2member_map_:
+            raise InvalidParameterValueException(
+                f"Input Authentication type: {authentication_type} is not in the allowed list: [password,no-password-required,iam]"
+            )
+
+        if (
+            no_password_required
+            and authentication_type != AuthenticationTypes.NOPASSWORD
+        ):
+            raise InvalidParameterCombinationException(
+                f"No password required flag is true but provided authentication type is {authentication_type}"
+            )
+
+        if passwords and authentication_type != AuthenticationTypes.PASSWORD:
+            raise InvalidParameterCombinationException(
+                f"Password field is not allowed with authentication type: {authentication_type}"
+            )
+
+        if not passwords and authentication_type == AuthenticationTypes.PASSWORD:
+            raise InvalidParameterCombinationException(
+                "A user with Authentication Mode: password, must have at least one password"
+            )
+
         user = User(
             account_id=self.account_id,
             region=self.region_name,
@@ -199,6 +287,7 @@ class ElastiCacheBackend(BaseBackend):
             passwords=passwords,
             access_string=access_string,
             no_password_required=no_password_required,
+            authentication_type=authentication_type,
         )
         self.users[user_id] = user
         return user
@@ -302,25 +391,24 @@ class ElastiCacheBackend(BaseBackend):
         self.cache_clusters[cache_cluster_id] = cache_cluster
         return cache_cluster
 
+    @paginate(PAGINATION_MODEL)
     def describe_cache_clusters(
         self,
         cache_cluster_id: str,
         max_records: int,
         marker: str,
-    ) -> Tuple[str, List[CacheCluster]]:
-        if marker is None:
-            marker = str(mock_random.uuid4())
+    ) -> List[CacheCluster]:
         if max_records is None:
             max_records = 100
         if cache_cluster_id:
             if cache_cluster_id in self.cache_clusters:
                 cache_cluster = self.cache_clusters[cache_cluster_id]
-                return marker, [cache_cluster]
+                return list([cache_cluster])
             else:
                 raise CacheClusterNotFound(cache_cluster_id)
         cache_clusters = list(self.cache_clusters.values())[:max_records]
 
-        return marker, cache_clusters
+        return cache_clusters
 
     def delete_cache_cluster(self, cache_cluster_id: str) -> CacheCluster:
         if cache_cluster_id:
@@ -330,5 +418,57 @@ class ElastiCacheBackend(BaseBackend):
                 return cache_cluster
         raise CacheClusterNotFound(cache_cluster_id)
 
+    def create_cache_subnet_group(
+        self,
+        cache_subnet_group_name: str,
+        cache_subnet_group_description: str,
+        subnet_ids: List[str],
+        tags: Optional[List[Dict[str, str]]],
+    ) -> CacheSubnetGroup:
+        if cache_subnet_group_name in self.cache_subnet_groups:
+            raise CacheSubnetGroupAlreadyExists(cache_subnet_group_name)
+
+        cache_subnet_group = CacheSubnetGroup(
+            account_id=self.account_id,
+            region_name=self.region_name,
+            cache_subnet_group_name=cache_subnet_group_name,
+            cache_subnet_group_description=cache_subnet_group_description,
+            subnet_ids=subnet_ids,
+            tags=tags,
+        )
+        self.cache_subnet_groups[cache_subnet_group_name] = cache_subnet_group
+        return cache_subnet_group
+
+    @paginate(PAGINATION_MODEL)
+    def describe_cache_subnet_groups(
+        self,
+        cache_subnet_group_name: str,
+    ) -> List[CacheSubnetGroup]:
+        if cache_subnet_group_name:
+            if cache_subnet_group_name in self.cache_subnet_groups:
+                cache_subnet_group = self.cache_subnet_groups[cache_subnet_group_name]
+                return list([cache_subnet_group])
+            else:
+                raise CacheSubnetGroupNotFound(cache_subnet_group_name)
+        cache_subnet_groups = list(self.cache_subnet_groups.values())
+        return cache_subnet_groups
+
+    def list_tags_for_resource(self, arn: str) -> List[Dict[str, str]]:
+        if self.arn_regex.match(arn):
+            arn_breakdown = arn.split(":")
+            resource_type = arn_breakdown[len(arn_breakdown) - 2]
+            resource_name = arn_breakdown[len(arn_breakdown) - 1]
+            if resource_type == "cluster":
+                if resource_name in self.cache_clusters:
+                    return self.cache_clusters[resource_name].get_tags()
+            elif resource_type == "subnetgroup":
+                if resource_name in self.cache_subnet_groups:
+                    return self.cache_subnet_groups[resource_name].get_tags()
+            else:
+                return []
+        else:
+            raise InvalidARNFault(arn)
+        return []
+
 
 elasticache_backends = BackendDict(ElastiCacheBackend, "elasticache")
