@@ -1,7 +1,12 @@
 from moto.core.responses import BaseResponse
 
-from .exceptions import PasswordRequired, PasswordTooShort
+from .exceptions import (
+    InvalidParameterCombinationException,
+    InvalidParameterValueException,
+    PasswordTooShort,
+)
 from .models import ElastiCacheBackend, elasticache_backends
+from .utils import VALID_AUTH_MODE_KEYS, VALID_ENGINE_TYPES, AuthenticationTypes
 
 
 class ElastiCacheResponse(BaseResponse):
@@ -19,14 +24,48 @@ class ElastiCacheResponse(BaseResponse):
         params = self._get_params()
         user_id = params.get("UserId")
         user_name = params.get("UserName")
-        engine = params.get("Engine")
+        engine = params.get("Engine", "").lower()
         passwords = params.get("Passwords", [])
-        no_password_required = self._get_bool_param("NoPasswordRequired", False)
-        password_required = not no_password_required
-        if password_required and not passwords:
-            raise PasswordRequired
+        no_password_required = self._get_bool_param("NoPasswordRequired")
+        authentication_mode = params.get("AuthenticationMode")
+        authentication_type = "null"
+
+        if no_password_required is not None:
+            authentication_type = (
+                AuthenticationTypes.NOPASSWORD.value
+                if no_password_required
+                else AuthenticationTypes.PASSWORD.value
+            )
+
+        if passwords:
+            authentication_type = AuthenticationTypes.PASSWORD.value
+
+        if engine not in VALID_ENGINE_TYPES:
+            raise InvalidParameterValueException(
+                f'Unknown parameter for Engine: "{engine}", must be one of: {", ".join(VALID_ENGINE_TYPES)}'
+            )
+
+        if authentication_mode:
+            for key in authentication_mode.keys():
+                if key not in VALID_AUTH_MODE_KEYS:
+                    raise InvalidParameterValueException(
+                        f'Unknown parameter in AuthenticationMode: "{key}", must be one of: {", ".join(VALID_AUTH_MODE_KEYS)}'
+                    )
+
+            authentication_type = authentication_mode.get("Type")
+            authentication_passwords = authentication_mode.get("Passwords", [])
+
+            if passwords and authentication_passwords:
+                raise InvalidParameterCombinationException(
+                    "Passwords provided via multiple arguments. Use only one argument"
+                )
+
+            # if passwords is empty, then we can use the authentication_passwords
+            passwords = passwords if passwords else authentication_passwords
+
         if any([len(p) < 16 for p in passwords]):
             raise PasswordTooShort
+
         access_string = params.get("AccessString")
         user = self.elasticache_backend.create_user(
             user_id=user_id,  # type: ignore[arg-type]
@@ -35,6 +74,7 @@ class ElastiCacheResponse(BaseResponse):
             passwords=passwords,
             access_string=access_string,  # type: ignore[arg-type]
             no_password_required=no_password_required,
+            authentication_type=authentication_type,
         )
         template = self.response_template(CREATE_USER_TEMPLATE)
         return template.render(user=user)
@@ -67,7 +107,7 @@ class ElastiCacheResponse(BaseResponse):
         cache_subnet_group_name = self._get_param("CacheSubnetGroupName")
         cache_security_group_names = self._get_param("CacheSecurityGroupNames")
         security_group_ids = self._get_param("SecurityGroupIds")
-        tags = self._get_param("Tags")
+        tags = (self._get_multi_param_dict("Tags") or {}).get("Tag", [])
         snapshot_arns = self._get_param("SnapshotArns")
         snapshot_name = self._get_param("SnapshotName")
         preferred_maintenance_window = self._get_param("PreferredMaintenanceWindow")
@@ -128,7 +168,8 @@ class ElastiCacheResponse(BaseResponse):
         cache_cluster_id = self._get_param("CacheClusterId")
         max_records = self._get_int_param("MaxRecords")
         marker = self._get_param("Marker")
-        marker, cache_clusters = self.elasticache_backend.describe_cache_clusters(
+
+        cache_clusters, marker = self.elasticache_backend.describe_cache_clusters(
             cache_cluster_id=cache_cluster_id,
             marker=marker,
             max_records=max_records,
@@ -144,6 +185,40 @@ class ElastiCacheResponse(BaseResponse):
         template = self.response_template(DELETE_CACHE_CLUSTER_TEMPLATE)
         return template.render(cache_cluster=cache_cluster)
 
+    def list_tags_for_resource(self) -> str:
+        arn = self._get_param("ResourceName")
+        template = self.response_template(LIST_TAGS_FOR_RESOURCE_TEMPLATE)
+        tags = self.elasticache_backend.list_tags_for_resource(arn)
+        return template.render(tags=tags)
+
+    def create_cache_subnet_group(self) -> str:
+        cache_subnet_group_name = self._get_param("CacheSubnetGroupName")
+        cache_subnet_group_description = self._get_param("CacheSubnetGroupDescription")
+        subnet_ids = self._get_multi_param_dict("SubnetIds").get("SubnetIdentifier", [])
+        tags = (self._get_multi_param_dict("Tags") or {}).get("Tag", [])
+        cache_subnet_group = self.elasticache_backend.create_cache_subnet_group(
+            cache_subnet_group_name=cache_subnet_group_name,
+            cache_subnet_group_description=cache_subnet_group_description,
+            subnet_ids=subnet_ids,
+            tags=tags,
+        )
+        template = self.response_template(CREATE_CACHE_SUBNET_GROUP_TEMPLATE)
+        return template.render(cache_subnet_group=cache_subnet_group)
+
+    def describe_cache_subnet_groups(self) -> str:
+        cache_subnet_group_name = self._get_param("CacheSubnetGroupName")
+        max_records = self._get_param("MaxRecords")
+        marker = self._get_param("Marker")
+        cache_subnet_groups, marker = (
+            self.elasticache_backend.describe_cache_subnet_groups(
+                cache_subnet_group_name=cache_subnet_group_name,
+                marker=marker,
+                max_records=max_records,
+            )
+        )
+        template = self.response_template(DESCRIBE_CACHE_SUBNET_GROUPS_TEMPLATE)
+        return template.render(marker=marker, cache_subnet_groups=cache_subnet_groups)
+
 
 USER_TEMPLATE = """<UserId>{{ user.id }}</UserId>
     <UserName>{{ user.name }}</UserName>
@@ -160,7 +235,9 @@ USER_TEMPLATE = """<UserId>{{ user.id }}</UserId>
       {% if user.no_password_required %}
       <Type>no-password</Type>
       {% else %}
-      <Type>password</Type>
+      <Type>{{ user.authentication_type }}</Type>
+      {% endif %}
+      {% if user.passwords %}
       <PasswordCount>{{ user.passwords|length }}</PasswordCount>
       {% endif %}
     </Authentication>
@@ -257,7 +334,7 @@ CREATE_CACHE_CLUSTER_TEMPLATE = """<CreateCacheClusterResponse xmlns="http://ela
       <LogFormat>{{ log_delivery_configuration.LogFormat }}</LogFormat>
       {% endfor %}
     </LogDeliveryConfigurations>
-    <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled }}</TransitEncryptionEnabled>
+    <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled|lower }}</TransitEncryptionEnabled>
     <TransitEncryptionMode>preferred</TransitEncryptionMode>
   </PendingModifiedValues>
   {% endif %}
@@ -294,7 +371,7 @@ CREATE_CACHE_CLUSTER_TEMPLATE = """<CreateCacheClusterResponse xmlns="http://ela
     <CustomerAvailabilityZone>{{ cache_cluster.preferred_availability_zone }}</CustomerAvailabilityZone>
     <CustomerOutpostArn>{{ cache_cluster.preferred_output_arn }}</CustomerOutpostArn>
   </CacheNodes>
-  <AutoMinorVersionUpgrade>{{ cache_cluster.auto_minor_version_upgrade }}</AutoMinorVersionUpgrade>
+  <AutoMinorVersionUpgrade>{{ cache_cluster.auto_minor_version_upgrade|lower }}</AutoMinorVersionUpgrade>
   <SecurityGroups>
   {% for security_group_id in cache_cluster.security_group_ids %}
     <SecurityGroupId>{{ security_group_id }}</SecurityGroupId>
@@ -308,7 +385,7 @@ CREATE_CACHE_CLUSTER_TEMPLATE = """<CreateCacheClusterResponse xmlns="http://ela
   {% endif %}
   <AuthTokenEnabled>true</AuthTokenEnabled>
   <AuthTokenLastModifiedDate>{{ cache_cluster.cache_cluster_create_time }}</AuthTokenLastModifiedDate>
-  <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled }}</TransitEncryptionEnabled>
+  <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled|lower }}</TransitEncryptionEnabled>
   <AtRestEncryptionEnabled>true</AtRestEncryptionEnabled>
   <ARN>{{ cache_cluster.arn }}</ARN>
   <ReplicationGroupLogDeliveryEnabled>true</ReplicationGroupLogDeliveryEnabled>
@@ -341,7 +418,7 @@ DESCRIBE_CACHE_CLUSTERS_TEMPLATE = """<DescribeCacheClustersResponse xmlns="http
     <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
   </ResponseMetadata>
   <DescribeCacheClustersResult>
-    <Marker>{{ marker }}</Marker>
+    {% if marker %}<Marker>{{ marker }}</Marker>{% endif %}
     <CacheClusters>
 {% for cache_cluster in cache_clusters %}
       <member>
@@ -383,7 +460,7 @@ DESCRIBE_CACHE_CLUSTERS_TEMPLATE = """<DescribeCacheClustersResponse xmlns="http
           </member>
 {% endfor %}
         </CacheNodes>
-        <AutoMinorVersionUpgrade>{{ cache_cluster.auto_minor_version_upgrade }}</AutoMinorVersionUpgrade>
+        <AutoMinorVersionUpgrade>{{ cache_cluster.auto_minor_version_upgrade|lower }}</AutoMinorVersionUpgrade>
         <SecurityGroups>
 {% for security_group in cache_cluster.security_groups %}
           <member>
@@ -397,7 +474,7 @@ DESCRIBE_CACHE_CLUSTERS_TEMPLATE = """<DescribeCacheClustersResponse xmlns="http
         <SnapshotWindow>{{ cache_cluster.snapshot_window }}</SnapshotWindow>
         <AuthTokenEnabled>{{ cache_cluster.auth_token_enabled }}</AuthTokenEnabled>
         <AuthTokenLastModifiedDate>{{ cache_cluster.auth_token_last_modified_date }}</AuthTokenLastModifiedDate>
-        <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled }}</TransitEncryptionEnabled>
+        <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled|lower }}</TransitEncryptionEnabled>
         <AtRestEncryptionEnabled>{{ cache_cluster.at_rest_encryption_enabled }}</AtRestEncryptionEnabled>
         <ARN>{{ cache_cluster.arn }}</ARN>
         <ReplicationGroupLogDeliveryEnabled>{{ cache_cluster.replication_group_log_delivery_enabled }}</ReplicationGroupLogDeliveryEnabled>
@@ -467,7 +544,7 @@ DELETE_CACHE_CLUSTER_TEMPLATE = """<DeleteCacheClusterResponse xmlns="http://ela
       <LogFormat>{{ log_delivery_configuration.LogFormat }}</LogFormat>
       {% endfor %}
     </LogDeliveryConfigurations>
-    <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled }}</TransitEncryptionEnabled>
+    <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled|lower }}</TransitEncryptionEnabled>
     <TransitEncryptionMode>preferred</TransitEncryptionMode>
   </PendingModifiedValues>
   {% endif %}
@@ -504,7 +581,7 @@ DELETE_CACHE_CLUSTER_TEMPLATE = """<DeleteCacheClusterResponse xmlns="http://ela
     <CustomerAvailabilityZone>{{ cache_cluster.preferred_availability_zone }}</CustomerAvailabilityZone>
     <CustomerOutpostArn>{{ cache_cluster.preferred_output_arn }}</CustomerOutpostArn>
   </CacheNodes>
-  <AutoMinorVersionUpgrade>{{ cache_cluster.auto_minor_version_upgrade }}</AutoMinorVersionUpgrade>
+  <AutoMinorVersionUpgrade>{{ cache_cluster.auto_minor_version_upgrade|lower }}</AutoMinorVersionUpgrade>
   <SecurityGroups>
   {% for security_group_id in cache_cluster.security_group_ids %}
     <SecurityGroupId>{{ security_group_id }}</SecurityGroupId>
@@ -518,7 +595,7 @@ DELETE_CACHE_CLUSTER_TEMPLATE = """<DeleteCacheClusterResponse xmlns="http://ela
   {% endif %}
   <AuthTokenEnabled>true</AuthTokenEnabled>
   <AuthTokenLastModifiedDate>{{ cache_cluster.cache_cluster_create_time }}</AuthTokenLastModifiedDate>
-  <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled }}</TransitEncryptionEnabled>
+  <TransitEncryptionEnabled>{{ cache_cluster.transit_encryption_enabled|lower }}</TransitEncryptionEnabled>
   <AtRestEncryptionEnabled>true</AtRestEncryptionEnabled>
   <ARN>{{ cache_cluster.arn }}</ARN>
   <ReplicationGroupLogDeliveryEnabled>true</ReplicationGroupLogDeliveryEnabled>
@@ -545,3 +622,92 @@ DELETE_CACHE_CLUSTER_TEMPLATE = """<DeleteCacheClusterResponse xmlns="http://ela
 </CacheCluster>
   </DeleteCacheClusterResult>
 </DeleteCacheClusterResponse>"""
+
+LIST_TAGS_FOR_RESOURCE_TEMPLATE = """<ListTagsForResourceResponse xmlns="http://elasticache.amazonaws.com/doc/2015-02-02/">
+  <ListTagsForResourceResult>
+    <TagList>
+    {%- for tag in tags -%}
+      <Tag>
+        <Key>{{ tag['Key'] }}</Key>
+        <Value>{{ tag['Value'] }}</Value>
+      </Tag>
+    {%- endfor -%}
+    </TagList>
+  </ListTagsForResourceResult>
+  <ResponseMetadata>
+    <RequestId>8c21ba39-a598-11e4-b688-194eaf8658fa</RequestId>
+  </ResponseMetadata>
+</ListTagsForResourceResponse>"""
+
+CREATE_CACHE_SUBNET_GROUP_TEMPLATE = """<CreateCacheSubnetGroupResponse xmlns="http://elasticache.amazonaws.com/doc/2015-02-02/">
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+  <CreateCacheSubnetGroupResult>
+    <CacheSubnetGroup>
+      <CacheSubnetGroupName>{{ cache_subnet_group.cache_subnet_group_name }}</CacheSubnetGroupName>
+      <CacheSubnetGroupDescription>{{ cache_subnet_group.cache_subnet_group_description }}</CacheSubnetGroupDescription>
+      <VpcId>{{ cache_subnet_group.vpc_id }}</VpcId>
+      <Subnets>
+        {% for subnet in cache_subnet_group.subnets_responses %}
+        <Subnet>
+          <SubnetIdentifier>{{ subnet.subnet_id }}</SubnetIdentifier>
+          <SubnetAvailabilityZone>
+            <Name>{{ subnet.subnet_az }}</Name>
+          </SubnetAvailabilityZone>
+          <SupportedNetworkTypes>
+            {% for network_type in subnet.subnet_supported_network_types %}
+              <member>{{ network_type }}</member>
+            {% endfor %}
+          </SupportedNetworkTypes>
+        </Subnet>
+        {% endfor %}
+      </Subnets>
+      <ARN>{{ cache_subnet_group.arn }}</ARN>
+      <SupportedNetworkTypes>
+        {% for network_type in cache_subnet_group.supported_network_types %}
+          <member>{{ network_type }}</member>
+        {% endfor %}
+      </SupportedNetworkTypes>
+    </CacheSubnetGroup>
+  </CreateCacheSubnetGroupResult>
+</CreateCacheSubnetGroupResponse>"""
+
+DESCRIBE_CACHE_SUBNET_GROUPS_TEMPLATE = """<DescribeCacheSubnetGroupsResponse xmlns="http://elasticache.amazonaws.com/doc/2015-02-02/">
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+  <DescribeCacheSubnetGroupsResult>
+    {% if marker %}<Marker>{{ marker }}</Marker>{% endif %}
+    <CacheSubnetGroups>
+      {% for cache_subnet_group in cache_subnet_groups %}
+      <member>
+        <CacheSubnetGroupName>{{ cache_subnet_group.cache_subnet_group_name }}</CacheSubnetGroupName>
+        <CacheSubnetGroupDescription>{{ cache_subnet_group.cache_subnet_group_description }}</CacheSubnetGroupDescription>
+        <VpcId>{{ cache_subnet_group.vpc_id }}</VpcId>
+        <Subnets>
+          {% for subnet in cache_subnet_group.subnets_responses %}
+          <Subnet>
+            <SubnetIdentifier>{{ subnet.subnet_id }}</SubnetIdentifier>
+            <SubnetAvailabilityZone>
+              <Name>{{ subnet.subnet_az }}</Name>
+            </SubnetAvailabilityZone>
+            <SupportedNetworkTypes>
+              {% for network_type in subnet.subnet_supported_network_types %}
+              <member>{{ network_type }}</member>
+              {% endfor %}
+            </SupportedNetworkTypes>
+          </Subnet>
+          {% endfor %}
+        </Subnets>
+        <ARN>{{ cache_subnet_group.arn }}</ARN>
+        <SupportedNetworkTypes>
+          {% for network_type in cache_subnet_group.supported_network_types %}
+          <member>{{ network_type }}</member>
+          {% endfor %}
+        </SupportedNetworkTypes>
+      </member>
+      {% endfor %}
+    </CacheSubnetGroups>
+  </DescribeCacheSubnetGroupsResult>
+</DescribeCacheSubnetGroupsResponse>"""
