@@ -1,6 +1,7 @@
 from moto.core.responses import BaseResponse
-from .models import elb_backends, ELBBackend, FakeLoadBalancer
+
 from .exceptions import DuplicateTagKeysError, LoadBalancerNotFoundError
+from .models import ELBBackend, FakeLoadBalancer, elb_backends
 
 
 class ELBResponse(BaseResponse):
@@ -188,6 +189,19 @@ class ELBResponse(BaseResponse):
                 load_balancer_name, connection_settings=connection_settings
             )
 
+        additional_attributes_raw = self._get_multi_param(
+            "LoadBalancerAttributes.AdditionalAttributes.member"
+        )
+        additional_attributes = []
+        for attr in additional_attributes_raw:
+            key = attr.get("Key")
+            value = attr.get("Value")
+            additional_attributes.append({"Key": key, "Value": value})
+
+        if additional_attributes:
+            self.elb_backend.modify_load_balancer_attributes(
+                load_balancer_name, additional_attributes=additional_attributes
+            )
         template = self.response_template(MODIFY_ATTRIBUTES_TEMPLATE)
         return template.render(
             load_balancer=load_balancer, attributes=load_balancer.attributes
@@ -200,7 +214,7 @@ class ELBResponse(BaseResponse):
         policy_type_name = self._get_param("PolicyTypeName")
         policy_attrs = self._get_multi_param("PolicyAttributes.member.")
 
-        self.elb_backend.create_lb_other_policy(
+        self.elb_backend.create_load_balancer_policy(
             load_balancer_name, policy_name, policy_type_name, policy_attrs
         )
 
@@ -269,8 +283,8 @@ class ELBResponse(BaseResponse):
         ]
         if mb_backend:
             policies = self._get_multi_param("PolicyNames.member")
-            self.elb_backend.set_load_balancer_policies_of_backend_server(
-                load_balancer_name, instance_port, policies  # type: ignore[arg-type]
+            self.elb_backend.set_load_balancer_policies_for_backend_server(
+                load_balancer_name, instance_port, policies
             )
         # else: explode?
 
@@ -297,7 +311,6 @@ class ELBResponse(BaseResponse):
         return template.render(instances=instances)
 
     def add_tags(self) -> str:
-
         for key, value in self.querystring.items():
             if "LoadBalancerNames.member" in key:
                 load_balancer_name = value[0]
@@ -405,7 +418,8 @@ class ELBResponse(BaseResponse):
         subnets = params.get("Subnets")
 
         all_subnets = self.elb_backend.attach_load_balancer_to_subnets(
-            load_balancer_name, subnets  # type: ignore[arg-type]
+            load_balancer_name,  # type: ignore[arg-type]
+            subnets,  # type: ignore[arg-type]
         )
         template = self.response_template(ATTACH_LB_TO_SUBNETS_TEMPLATE)
         return template.render(subnets=all_subnets)
@@ -416,7 +430,8 @@ class ELBResponse(BaseResponse):
         subnets = params.get("Subnets")
 
         all_subnets = self.elb_backend.detach_load_balancer_from_subnets(
-            load_balancer_name, subnets  # type: ignore[arg-type]
+            load_balancer_name,  # type: ignore[arg-type]
+            subnets,  # type: ignore[arg-type]
         )
         template = self.response_template(DETACH_LB_FROM_SUBNETS_TEMPLATE)
         return template.render(subnets=all_subnets)
@@ -742,6 +757,14 @@ DESCRIBE_ATTRIBUTES_TEMPLATE = """<DescribeLoadBalancerAttributesResponse  xmlns
         <Timeout>{{ attributes["connection_draining"]["timeout"] }}</Timeout>
         {% endif %}
       </ConnectionDraining>
+      <AdditionalAttributes>
+        {% for attribute in attributes.additional_attributes %}
+        <member>
+          <Key>{{ attribute[0] }}</Key>
+          <Value>{{ attribute[1] }}</Value>
+        </member>
+        {% endfor %}
+      </AdditionalAttributes>
     </LoadBalancerAttributes>
   </DescribeLoadBalancerAttributesResult>
   <ResponseMetadata>
@@ -776,6 +799,14 @@ MODIFY_ATTRIBUTES_TEMPLATE = """<ModifyLoadBalancerAttributesResponse xmlns="htt
         <Enabled>false</Enabled>
         {% endif %}
       </ConnectionDraining>
+      <AdditionalAttributes>
+        {% for attribute in attributes.additional_attributes %}
+        <member>
+          <Key>{{ attribute[0] }}</Key>
+          <Value>{{ attribute[1] }}</Value>
+        </member>
+        {% endfor %}
+      </AdditionalAttributes>
     </LoadBalancerAttributes>
   </ModifyLoadBalancerAttributesResult>
   <ResponseMetadata>
