@@ -5,6 +5,7 @@ from urllib.parse import urlparse
 
 from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
+from moto.core.utils import utcnow
 
 
 class InstanceMetadataResponse(BaseResponse):
@@ -14,9 +15,9 @@ class InstanceMetadataResponse(BaseResponse):
     def backends(self) -> None:
         pass
 
-    def metadata_response(
-        self,
-        request: Any,  # pylint: disable=unused-argument
+    @staticmethod
+    def metadata_response(  # type: ignore
+        request: Any,
         full_url: str,
         headers: Any,
     ) -> TYPE_RESPONSE:
@@ -27,7 +28,7 @@ class InstanceMetadataResponse(BaseResponse):
         """
 
         parsed_url = urlparse(full_url)
-        tomorrow = datetime.datetime.utcnow() + datetime.timedelta(days=1)
+        tomorrow = utcnow() + datetime.timedelta(days=1)
         credentials = dict(
             AccessKeyId="test-key",
             SecretAccessKey="test-secret-key",
@@ -54,4 +55,12 @@ class InstanceMetadataResponse(BaseResponse):
             raise NotImplementedError(
                 f"The {path} metadata path has not been implemented"
             )
+        try:
+            from werkzeug.datastructures.headers import EnvironHeaders
+
+            if isinstance(headers, EnvironHeaders):
+                # We should be returning a generic dict here, not werkzeug-specific classes
+                headers = {key: value for key, value in headers}
+        except ImportError:
+            pass
         return 200, headers, result
