@@ -84,6 +84,7 @@ class CoreNetwork(BaseModel):
         policy_document: str,
         client_token: str,
     ):
+        self.owner_account_id = account_id
         self.global_network_id = global_network_id
         self.description = description
         self.tags = tags or []
@@ -100,6 +101,7 @@ class CoreNetwork(BaseModel):
             "CoreNetworkId": self.core_network_id,
             "CoreNetworkArn": self.core_network_arn,
             "GlobalNetworkId": self.global_network_id,
+            "OwnerAccountId": self.owner_account_id,
             "Description": self.description,
             "Tags": self.tags,
             "PolicyDocument": self.policy_document,
@@ -270,6 +272,11 @@ class NetworkManagerBackend(BaseBackend):
         except (KeyError, ValueError, AttributeError):
             raise ResourceNotFound(arn)
 
+    def update_resource_state(self, resource_arn: str, state: str) -> None:
+        # Acceptable states: PENDING, AVAILABLE, DELETING, UPDATING
+        resource = self._get_resource_from_arn(resource_arn)
+        resource.state = state
+
     def create_global_network(
         self,
         description: Optional[str],
