@@ -5,11 +5,13 @@ from typing import Any, Dict, Iterable, List, Optional
 
 from dateutil.tz import tzutc
 
-from moto.core import BackendDict, BaseBackend, BaseModel, CloudFormationModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel, CloudFormationModel
 from moto.core.utils import iso_8601_datetime_with_milliseconds
 from moto.ec2 import ec2_backends
 from moto.ec2.models.security_groups import SecurityGroup as EC2SecurityGroup
 from moto.moto_api._internal import mock_random
+from moto.utilities.utils import get_partition
 
 from .exceptions import (
     ClusterAlreadyExistsFaultError,
@@ -50,10 +52,7 @@ class TaggableResourceMixin:
 
     @property
     def arn(self) -> str:
-        return (
-            f"arn:aws:redshift:{self.region}:{self.account_id}"
-            f":{self.resource_type}:{self.resource_id}"
-        )
+        return f"arn:{get_partition(self.region)}:redshift:{self.region}:{self.account_id}:{self.resource_type}:{self.resource_id}"
 
     def create_tags(self, tags: List[Dict[str, str]]) -> List[Dict[str, str]]:
         new_keys = [tag_set["Key"] for tag_set in tags]
@@ -160,6 +159,16 @@ class Cluster(TaggableResourceMixin, CloudFormationModel):
         self.kms_key_id = kms_key_id
         self.cluster_snapshot_copy_status: Optional[Dict[str, Any]] = None
         self.total_storage_capacity = 0
+        self.logging_details = {
+            "LoggingEnabled": "false",  # Lower case is required in response so we use string to simplify
+            "BucketName": "",
+            "S3KeyPrefix": "",
+            "LastSuccessfulDeliveryTime": datetime.datetime.now(),
+            "LastFailureTime": datetime.datetime.now(),
+            "LastFailureMessage": "",
+            "LogDestinationType": "",
+            "LogExports": [],
+        }
 
     @staticmethod
     def cloudformation_name_type() -> str:
@@ -276,7 +285,7 @@ class Cluster(TaggableResourceMixin, CloudFormationModel):
             "MasterUserPassword": "****",
             "ClusterVersion": self.cluster_version,
             "VpcSecurityGroups": [
-                {"Status": "active", "VpcSecurityGroupId": group.id}  # type: ignore
+                {"Status": "active", "VpcSecurityGroupId": group.id}
                 for group in self.vpc_security_groups
             ],
             "ClusterSubnetGroupName": self.cluster_subnet_group_name,
@@ -328,9 +337,9 @@ class Cluster(TaggableResourceMixin, CloudFormationModel):
                 "EstimatedTimeToCompletionInSeconds": 123,
             }
         if self.cluster_snapshot_copy_status is not None:
-            json_response[
-                "ClusterSnapshotCopyStatus"
-            ] = self.cluster_snapshot_copy_status
+            json_response["ClusterSnapshotCopyStatus"] = (
+                self.cluster_snapshot_copy_status
+            )
         return json_response
 
 
@@ -594,17 +603,6 @@ class RedshiftBackend(BaseBackend):
         }
         self.snapshot_copy_grants: Dict[str, SnapshotCopyGrant] = {}
 
-    @staticmethod
-    def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
-        """Default VPC endpoint service."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "redshift"
-        ) + BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "redshift-data", policy_supported=False
-        )
-
     def enable_snapshot_copy(self, **kwargs: Any) -> Cluster:
         cluster_identifier = kwargs["cluster_identifier"]
         cluster = self.clusters[cluster_identifier]
@@ -1096,5 +1094,36 @@ class RedshiftBackend(BaseBackend):
             }
         raise ClusterNotFoundError(cluster_identifier)
 
+    def enable_logging(
+        self,
+        cluster_identifier: str,
+        bucket_name: str,
+        s3_key_prefix: str,
+        log_destination_type: str,
+        log_exports: List[str],
+    ) -> Dict[str, Any]:
+        if cluster_identifier not in self.clusters:
+            raise ClusterNotFoundError(cluster_identifier)
+        cluster = self.clusters[cluster_identifier]
+        cluster.logging_details["LoggingEnabled"] = "true"
+        cluster.logging_details["BucketName"] = bucket_name
+        cluster.logging_details["S3KeyPrefix"] = s3_key_prefix
+        cluster.logging_details["LogDestinationType"] = log_destination_type
+        cluster.logging_details["LogExports"] = log_exports
+        return cluster.logging_details
+
+    def disable_logging(self, cluster_identifier: str) -> Dict[str, Any]:
+        if cluster_identifier not in self.clusters:
+            raise ClusterNotFoundError(cluster_identifier)
+        cluster = self.clusters[cluster_identifier]
+        cluster.logging_details["LoggingEnabled"] = "false"
+        return cluster.logging_details
+
+    def describe_logging_status(self, cluster_identifier: str) -> Dict[str, Any]:
+        if cluster_identifier not in self.clusters:
+            raise ClusterNotFoundError(cluster_identifier)
+        cluster = self.clusters[cluster_identifier]
+        return cluster.logging_details
+
 
 redshift_backends = BackendDict(RedshiftBackend, "redshift")
