@@ -1,47 +1,49 @@
+import datetime
+import hashlib
+import json
 import re
-from dataclasses import dataclass
-from typing import Any, Dict, List, Iterator, Optional, Tuple
-from typing import DefaultDict
-
+import time
 from collections import defaultdict
+from dataclasses import dataclass
+from typing import Any, DefaultDict, Dict, Iterator, List, Optional, Tuple
 
-from moto.core import BaseBackend, BackendDict, BaseModel, CloudFormationModel
+import yaml
+
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel, CloudFormationModel
 from moto.core.exceptions import RESTError
 from moto.core.utils import utcnow
 from moto.ec2 import ec2_backends
+from moto.moto_api._internal import mock_random as random
 from moto.secretsmanager import secretsmanager_backends
 from moto.secretsmanager.exceptions import SecretsManagerClientError
 from moto.utilities.utils import load_resource
 
-import datetime
-import time
-import json
-import yaml
-import hashlib
-from moto.moto_api._internal import mock_random as random
-from .utils import parameter_arn, convert_to_params
 from .exceptions import (
-    ValidationException,
-    InvalidFilterValue,
-    InvalidFilterOption,
-    InvalidFilterKey,
-    ParameterVersionLabelLimitExceeded,
-    ParameterVersionNotFound,
-    ParameterNotFound,
-    DocumentAlreadyExists,
-    InvalidDocumentOperation,
     AccessDeniedException,
+    DocumentAlreadyExists,
+    DocumentPermissionLimit,
+    DoesNotExistException,
+    DuplicateDocumentContent,
+    DuplicateDocumentVersionName,
     InvalidDocument,
     InvalidDocumentContent,
+    InvalidDocumentOperation,
     InvalidDocumentVersion,
-    DuplicateDocumentVersionName,
-    DuplicateDocumentContent,
-    ParameterMaxVersionLimitExceeded,
-    DocumentPermissionLimit,
+    InvalidFilterKey,
+    InvalidFilterOption,
+    InvalidFilterValue,
     InvalidPermissionType,
     InvalidResourceId,
     InvalidResourceType,
+    ParameterAlreadyExists,
+    ParameterMaxVersionLimitExceeded,
+    ParameterNotFound,
+    ParameterVersionLabelLimitExceeded,
+    ParameterVersionNotFound,
+    ValidationException,
 )
+from .utils import convert_to_params, parameter_arn
 
 
 class ParameterDict(DefaultDict[str, List["Parameter"]]):
@@ -131,7 +133,7 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
 
     def _get_secretsmanager_parameter(self, secret_name: str) -> List["Parameter"]:
         secrets_backend = secretsmanager_backends[self.account_id][self.region_name]
-        secret = secrets_backend.describe_secret(secret_name)
+        secret = secrets_backend.describe_secret(secret_name).to_dict()
         version_id_to_stage = secret["VersionIdsToStages"]
         # Sort version ID's so that AWSCURRENT is last
         sorted_version_ids = [
@@ -141,7 +143,7 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
             secrets_backend.get_secret_value(
                 secret_name,
                 version_id=version_id,
-                version_stage=None,
+                version_stage=None,  # type: ignore[arg-type]
             )
             for version_id in sorted_version_ids
         ]
@@ -149,7 +151,7 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
             Parameter(
                 account_id=self.account_id,
                 name=secret["Name"],
-                value=val.get("SecretString"),
+                value=val.get("SecretString"),  # type: ignore[arg-type]
                 parameter_type="SecureString",
                 description=secret.get("Description"),
                 allowed_pattern=None,
@@ -208,9 +210,10 @@ class Parameter(CloudFormationModel):
         last_modified_date: float,
         version: int,
         data_type: str,
-        tags: Optional[List[Dict[str, str]]] = None,
         labels: Optional[List[str]] = None,
         source_result: Optional[str] = None,
+        tier: Optional[str] = None,
+        policies: Optional[str] = None,
     ):
         self.account_id = account_id
         self.name = name
@@ -221,9 +224,10 @@ class Parameter(CloudFormationModel):
         self.last_modified_date = last_modified_date
         self.version = version
         self.data_type = data_type
-        self.tags = tags or []
         self.labels = labels or []
         self.source_result = source_result
+        self.tier = tier
+        self.policies = policies
 
         if self.parameter_type == "SecureString":
             if not self.keyid:
@@ -255,7 +259,17 @@ class Parameter(CloudFormationModel):
             "Version": self.version,
             "LastModifiedDate": round(self.last_modified_date, 3),
             "DataType": self.data_type,
+            "Tier": self.tier,
         }
+        if self.policies:
+            try:
+                policy_list = json.loads(self.policies)
+                r["Policies"] = [
+                    {"PolicyText": p, "PolicyType": p, "PolicyStatus": "Finished"}
+                    for p in policy_list
+                ]
+            except json.JSONDecodeError:
+                pass
         if self.source_result:
             r["SourceResult"] = self.source_result
 
@@ -316,10 +330,10 @@ class Parameter(CloudFormationModel):
             "overwrite": properties.get("Overwrite", False),
             "tags": properties.get("Tags", None),
             "data_type": properties.get("DataType", "text"),
+            "tier": properties.get("Tier"),
+            "policies": properties.get("Policies"),
         }
-        ssm_backend.put_parameter(**parameter_args)
-        parameter = ssm_backend.get_parameter(properties.get("Name"))
-        return parameter
+        return ssm_backend.put_parameter(**parameter_args)
 
     @classmethod
     def update_from_cloudformation_json(  # type: ignore[misc]
@@ -359,7 +373,7 @@ MAX_TIMEOUT_SECONDS = 3600
 
 
 def generate_ssm_doc_param_list(
-    parameters: Dict[str, Any]
+    parameters: Dict[str, Any],
 ) -> Optional[List[Dict[str, Any]]]:
     if not parameters:
         return None
@@ -442,7 +456,6 @@ class Documents(BaseModel):
         version_name: Optional[str] = None,
         strict: bool = True,
     ) -> "Document":
-
         if document_version == "$LATEST":
             ssm_document: Optional["Document"] = self.get_latest_version()
         elif version_name and document_version:
@@ -547,7 +560,6 @@ class Documents(BaseModel):
                     self.permissions.pop(account_id, None)
 
     def describe_permissions(self) -> Dict[str, Any]:
-
         permissions_ordered_by_date = sorted(
             self.permissions.values(), key=lambda p: p.created_at
         )
@@ -678,7 +690,6 @@ class Command(BaseModel):
         targets: Optional[List[Dict[str, Any]]] = None,
         backend_region: str = "us-east-1",
     ):
-
         if instance_ids is None:
             instance_ids = []
 
@@ -1166,25 +1177,17 @@ class SimpleSystemManagerBackend(BaseBackend):
         super().__init__(region_name, account_id)
         self._parameters = ParameterDict(account_id, region_name)
 
-        self._resource_tags: DefaultDict[
-            str, DefaultDict[str, Dict[str, str]]
-        ] = defaultdict(lambda: defaultdict(dict))
+        self._resource_tags: DefaultDict[str, DefaultDict[str, Dict[str, str]]] = (
+            defaultdict(lambda: defaultdict(dict))
+        )
         self._commands: List[Command] = []
         self._errors: List[str] = []
         self._documents: Dict[str, Documents] = {}
 
         self.windows: Dict[str, FakeMaintenanceWindow] = dict()
         self.baselines: Dict[str, FakePatchBaseline] = dict()
-
-    @staticmethod
-    def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
-        """Default VPC endpoint services."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "ssm"
-        ) + BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "ssmmessages"
+        self.ssm_prefix = (
+            f"arn:{self.partition}:ssm:{self.region_name}:{self.account_id}:parameter"
         )
 
     def _generate_document_information(
@@ -1336,7 +1339,6 @@ class SimpleSystemManagerBackend(BaseBackend):
     def get_document(
         self, name: str, document_version: str, version_name: str, document_format: str
     ) -> Dict[str, Any]:
-
         documents = self._get_documents(name)
         ssm_document = documents.find(document_version, version_name)
 
@@ -1488,7 +1490,6 @@ class SimpleSystemManagerBackend(BaseBackend):
         shared_document_version: str,
         permission_type: str,
     ) -> None:
-
         account_id_regex = re.compile(r"^(all|[0-9]{12})$", re.IGNORECASE)
         version_regex = re.compile(r"^([$]LATEST|[$]DEFAULT|[$]ALL)$")
 
@@ -1654,7 +1655,6 @@ class SimpleSystemManagerBackend(BaseBackend):
         filter_keys = []
         for filter_obj in parameter_filters or []:
             key = filter_obj["Key"]
-            values = filter_obj.get("Values")
 
             if key == "Path":
                 option = filter_obj.get("Option", "OneLevel")
@@ -1671,7 +1671,9 @@ class SimpleSystemManagerBackend(BaseBackend):
                     f"The following filter key is not valid: {key}. Valid filter keys include: [Type, KeyId]."
                 )
 
-            if key in ["Name", "Type", "Path", "Tier", "Keyid"] and not values:
+            if key in ["Name", "Type", "Path", "Tier", "Keyid"] and not filter_obj.get(
+                "Values"
+            ):
                 raise InvalidFilterValue(
                     "The following filter values are missing : null for filter key Name."
                 )
@@ -1682,16 +1684,19 @@ class SimpleSystemManagerBackend(BaseBackend):
                 )
 
             if key == "Path":
+                path_values = filter_obj["Values"]
                 if option not in ["Recursive", "OneLevel"]:
                     raise InvalidFilterOption(
                         f"The following filter option is not valid: {option}. Valid options include: [Recursive, OneLevel]."
                     )
-                if any(value.lower().startswith(("/aws", "/ssm")) for value in values):
+                if any(
+                    value.lower().startswith(("/aws", "/ssm")) for value in path_values
+                ):
                     raise ValidationException(
                         'Filters for common parameters can\'t be prefixed with "aws" or "ssm" (case-insensitive). '
                         "When using global parameters, please specify within a global namespace."
                     )
-                for value in values:
+                for value in path_values:
                     if value.lower().startswith(("/aws", "/ssm")):
                         raise ValidationException(
                             'Filters for common parameters can\'t be prefixed with "aws" or "ssm" (case-insensitive). '
@@ -1711,14 +1716,16 @@ class SimpleSystemManagerBackend(BaseBackend):
                         )
 
             if key == "Tier":
-                for value in values:
+                tier_values = filter_obj["Values"]
+                for value in tier_values:
                     if value not in ["Standard", "Advanced", "Intelligent-Tiering"]:
                         raise InvalidFilterOption(
                             f"The following filter value is not valid: {value}. Valid values include: [Standard, Advanced, Intelligent-Tiering]."
                         )
 
             if key == "Type":
-                for value in values:
+                type_values = filter_obj["Values"]
+                for value in type_values:
                     if value not in ["String", "StringList", "SecureString"]:
                         raise InvalidFilterOption(
                             f"The following filter value is not valid: {value}. Valid values include: [String, StringList, SecureString]."
@@ -1810,7 +1817,6 @@ class SimpleSystemManagerBackend(BaseBackend):
     def get_parameter_history(
         self, name: str, next_token: Optional[str], max_results: int = 50
     ) -> Tuple[Optional[List[Parameter]], Optional[str]]:
-
         if max_results > PARAMETER_HISTORY_MAX_RESULTS:
             raise ValidationException(
                 "1 validation error detected: "
@@ -1842,6 +1848,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         self, parameter: Parameter, filters: Optional[List[Dict[str, Any]]] = None
     ) -> bool:
         """Return True if the given parameter matches all the filters"""
+        parameter_tags = self.list_tags_for_resource("Parameter", parameter.name)
         for filter_obj in filters or []:
             key = filter_obj["Key"]
             values = filter_obj.get("Values", [])
@@ -1871,7 +1878,11 @@ class SimpleSystemManagerBackend(BaseBackend):
                 else:
                     continue
             elif key.startswith("tag:"):
-                what = [tag["Value"] for tag in parameter.tags if tag["Key"] == key[4:]]
+                what = [
+                    tag_value
+                    for tag_key, tag_value in parameter_tags.items()
+                    if tag_key == key[4:]
+                ]
 
             if what is None or what == []:
                 return False
@@ -1917,6 +1928,9 @@ class SimpleSystemManagerBackend(BaseBackend):
         return True
 
     def get_parameter(self, name: str) -> Optional[Parameter]:
+        if name.startswith(self.ssm_prefix):
+            name = name.replace(self.ssm_prefix, "")
+
         name_parts = name.split(":")
         name_prefix = name_parts[0]
 
@@ -2034,7 +2048,9 @@ class SimpleSystemManagerBackend(BaseBackend):
         overwrite: bool,
         tags: List[Dict[str, str]],
         data_type: str,
-    ) -> Optional[int]:
+        tier: Optional[str],
+        policies: Optional[str],
+    ) -> Parameter:
         if not value:
             raise ValidationException(
                 "1 validation error detected: Value '' at 'value' failed to satisfy"
@@ -2097,7 +2113,7 @@ class SimpleSystemManagerBackend(BaseBackend):
             version = previous_parameter.version + 1
 
             if not overwrite:
-                return None
+                raise ParameterAlreadyExists
             # overwriting a parameter, Type is not included in boto3 call
             if not parameter_type and overwrite:
                 parameter_type = previous_parameter.parameter_type
@@ -2106,28 +2122,47 @@ class SimpleSystemManagerBackend(BaseBackend):
                 self._check_for_parameter_version_limit_exception(name)
                 previous_parameter_versions.pop(0)
 
-        last_modified_date = time.time()
-        self._parameters[name].append(
-            Parameter(
-                account_id=self.account_id,
-                name=name,
-                value=value,
-                parameter_type=parameter_type,
-                description=description,
-                allowed_pattern=allowed_pattern,
-                keyid=keyid,
-                last_modified_date=last_modified_date,
-                version=version,
-                tags=tags or [],
-                data_type=data_type,
+            # Ensure all the previous values that we didn't overwrite are preserved
+            value = value if value is not None else previous_parameter.value
+            description = (
+                description
+                if description is not None
+                else previous_parameter.description
             )
+            allowed_pattern = (
+                allowed_pattern
+                if allowed_pattern is not None
+                else previous_parameter.allowed_pattern
+            )
+            keyid = keyid if keyid is not None else previous_parameter.keyid
+            data_type = (
+                data_type if data_type is not None else previous_parameter.data_type
+            )
+            tier = tier if tier is not None else previous_parameter.tier
+            policies = policies if policies is not None else previous_parameter.policies
+
+        last_modified_date = time.time()
+        new_param = Parameter(
+            account_id=self.account_id,
+            name=name,
+            value=value,
+            parameter_type=parameter_type,
+            description=description,
+            allowed_pattern=allowed_pattern,
+            keyid=keyid,
+            last_modified_date=last_modified_date,
+            version=version,
+            data_type=data_type,
+            tier=tier,
+            policies=policies,
         )
+        self._parameters[name].append(new_param)
 
         if tags:
             tag_dict = {t["Key"]: t["Value"] for t in tags}
             self.add_tags_to_resource("Parameter", name, tag_dict)
 
-        return version
+        return new_param
 
     def add_tags_to_resource(
         self, resource_type: str, resource_id: str, tags: Dict[str, str]
@@ -2288,9 +2323,10 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def get_maintenance_window(self, window_id: str) -> FakeMaintenanceWindow:
         """
-        The window is assumed to exist - no error handling has been implemented yet.
         The NextExecutionTime-field is not returned.
         """
+        if window_id not in self.windows:
+            raise DoesNotExistException(window_id)
         return self.windows[window_id]
 
     def describe_maintenance_windows(
@@ -2310,8 +2346,10 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def delete_maintenance_window(self, window_id: str) -> None:
         """
-        Assumes the provided WindowId exists. No error handling has been implemented yet.
+        Delete a maintenance window.
         """
+        if window_id not in self.windows:
+            raise DoesNotExistException(window_id)
         del self.windows[window_id]
 
     def create_patch_baseline(
@@ -2442,7 +2480,6 @@ class SimpleSystemManagerBackend(BaseBackend):
         cutoff_behavior: Optional[str],
         alarm_configurations: Optional[Dict[str, Any]],
     ) -> str:
-
         window = self.get_maintenance_window(window_id)
         task = FakeMaintenanceWindowTask(
             window_id,
